*to use this .do file you must have the following user-written program installed: dsconcat
*dsconcat will append several files at once, and this is done later in the .do file
*this program can be installed by typing "ssc install dsconcat" in the command window
*if this doesn't work check to be sure your http proxy is set up. InStata, go to Edit-Preferences-General Preferences-Internet.
*There should be an IP address and a port number under the first HTTP Proxy checkbox. If not, call Rolando.

*------------------------------------------------Take Each Wave File and Keep Only Variables We Want-------------------------------------*
clear
cd "$dire\Wave Files\2001\"

log using merge_all_waves, replace

set memory 1100M

set more off

*the individual wave files are approx 500MB so we must set memory high
*you may have to use the STATA on the server if your computer will not 
*provide the necessary memory

use 01w1

do "$dire\Programs\keep01.do"

*the above command will keep from each wave only the variables we care about

save 01k_w1, replace

clear

use 01w2

do "$dire\Programs\keep01.do"

save 01k_w2, replace

clear

use 01w3

do "$dire\Programs\keep01.do"

save 01k_w3, replace

clear

use 01w4

do "$dire\Programs\keep01.do"

save 01k_w4, replace

clear

use 01w5

do "$dire\Programs\keep01.do"

save 01k_w5, replace

clear

use 01w6

do "$dire\Programs\keep01.do"

save 01k_w6, replace

clear

use 01w7

do "$dire\Programs\keep01.do"

save 01k_w7, replace

clear

use 01w8

do "$dire\Programs\keep01.do"

save 01k_w8, replace

clear

use 01w9

do "$dire\Programs\keep01.do"

save 01k_w9, replace

clear

*------------------------------------------------Concatenate All 2001 Wave Files Into One Large 2001 Data File---------------------------*

dsconcat 01k_w1 01k_w2 01k_w3 01k_w4 01k_w5 01k_w6 01k_w7 01k_w8 01k_w9

*now we will save the file with all kept variables and all waves appended

save "$dire\Assembled Data\01_all", replace

*-----------------------------Sort Variables to Order Observations By Person then by Year and Month & Create Unique Identifier---------------*

*now we will sort the variables by "sample unit id", "person number", "wave of data collection", 
*"calendar year", and "calendar month" 

sort ssuid epppnum swave rhcalyr rhcalmn

*now move "person number" variable beside "sample unit id" variable

order epppnum, after(ssuid)

*now generate a new variable that concatonates the "sample unit id" variable and the "person number" 
*to make a "unique identifier" (uid) varaible for each individual in the dataset so that we can 
*analyze data by individual

egen uid = concat(ssuid epppnum)

label variable uid "Unique Identifier"

*now move "unique identifier" beside "person number" just to keep all of our identity-type 
*variables together

order uid, after(epppnum)

*now we will sort our observations so that they are lined up first by "uid", then by "calendar year", 
*and then "calendar month"

sort uid  rhcalyr rhcalmn

*now lets check to see if we have any duplicates of individuals in our dataset
*we will check to be certain that each "unique identifier" has only one "calendar year" and 
*"calendar month" associated with them so that we know they only have one observation per sample period
*there should be no duplicates (in other words there should be a 0 in the surplus column)

duplicates report uid rhcalyr rhcalmn 

*The duplicates report should show 0 duplicates

*---------------------------------------Drop <18 & >65, Drop Military, Code for Education, Race, Age, Disability, Kids, Marital Status-----* *---------------------------------------Homeownership, Employment, and Create Observation Number for Each Response From Each Person--------*

*now we will drop all observations where the age of the person is < 18 or > 65

drop if (tage<18 | tage>65)

*now we will drop all observations where person is enrolled in college (either full-time or part-time)
*renroll=3 is defined as "Not Enrolled" for our dataset so we will drop where renroll is NOT equal to 3

drop if renroll!=3

*now we will drop any person who was in the military at any time during the sample

by uid: gen military=1 if eafnow==1

replace military=0 if military==.

label variable military "Equals 1 if in military that month"

by uid: egen totmilitary=total(military)

*the above line of code will put the total number of months during the survey that a person was in the military beside each of that person's *observations. if that number is greater than 0, the line of code 2 lines below will drop all of that person's observations entirely.

label variable totmilitary "Greater than 0 if in military at any time during survey"

drop if totmilitary>0

*Now we will set up dummies for education that are more compact then the 17 categories in the SIPP questionaire

gen educ=1 if (eeducate>=31 & eeducate<=38) 

*educ=1 if less than high school education

label variable educ "New 1-5 education categories"

replace educ=2 if eeducate==39

*educ=2 if high school diploma

replace educ=3 if (eeducate>=40 & eeducate<=43)

*educ=3 if some college

replace educ=4 if eeducate==44

*educ=4 if college degree

replace educ=5 if (eeducate>=45)

*educ=5 if Master's degree or higher

*Now we will combine education levels 4 and 5 to be Bachelor's and higher. We will create a new education variable called educ2
*to do this and keep the previous educ variable so that we also have an education variable with Bachelor's and Graduate/Professional
*degrees separate

gen educ2=educ

replace educ2=6 if educ==4 | educ==5

label variable educ2 "New 1-3 and 6 education categories"

*educ2=6 for combining Bachelor's and Graduate/Professional degrees

*Now we will set up dummies for race that are more compact than the 4 categories in the SIPP questionaire

gen race=1 if erace==1

*race=1 if person is white

label variable race "New 1-2 race categories"

replace race=2 if (erace>1)

*race=2 if person is non-white

*Now we will set up dummies for age that are more compact than the SIPP questionaire

gen age=1 if tage<=24

replace age=2 if (tage>24 & tage<=54)

replace age=3 if (tage>54 & tage<=65)

label variable age "New 1-3 age categories"

*Now we will label a person as disabled if they were disabled at any time during the sample

by uid: gen disabled=1 if edisabl==1

replace disabled=0 if disabled==.

label variable disabled "Equals 1 if disabled that month"

by uid: egen totdisabled=total(disabled)

label variable totdisabled "Greater than 0 if disabled at any time during survey"

*Now we will set up dummies for number of kids. "0" if 0 kids, "1" if 1 or 2 kids, "2" if 3 or more kids.

gen kids=0 if rfnkids==0

replace kids=1 if rfnkids>0 & rfnkids<3

replace kids=2 if rfnkids>=3

label variable kids "New 1-3 kid categories"

*Now we will set up dummies for marital status. "1" if married with spouse present or absent, "2" if divorced or separated,
*"3" if widowed, and "4" if never married.

gen maritalstat=1 if ems==1 | ems==2

replace maritalstat=2 if ems==4 | ems==5

replace maritalstat=3 if ems==3

replace maritalstat=4 if ems==6 

label variable maritalstat "New 1-4 marital status categories"

*Now we will set up dummies for homeownership. "1" if owns home, "0" if otherwise.

gen homeown=1 if etenure==1

replace homeown=0 if etenure==2 | etenure==3

label variable homeown "Equals 1 if homeowner"

*Now we will set up dummies for employment status. "1" if employed entire month, "0" if otherwise.

gen employed=1 if rmesr==1 | rmesr==2

replace employed=0 if employed!=1

label variable employed "Equals 1 if employed entire month"

*Now we will generate observation numbers for the observations of each person in the sample

by uid: gen obsno=_n

label variable obsno "Equals observation number associated with particular person's response"
*For example if an observation is from the 4th month that particular person participated in the panel, obsno would equal 4


*----------------------------------------------------Flag MSA Movers Within the 2001 Data Set--------------------------------------*

*now we will flag movers within the dataset
*we will generate a varable called "msamove" and give it a value of 1 if the "uid" are the same but 
*the "MSA Code" changes over the monthly observations for each unique person

by uid: gen msamove=1 if uid[_n]==uid[_n-1] & tmsa[_n]~=tmsa[_n-1] 

replace msamove=0 if msamove==.

label variable msamove "Equals 1 if moved MSA location from prior month"

count if msamove==1

*the above value should equal 

*now we will generate variables that will tell us whether the moves that did take place were 
*"Metro to Metro", "Non-Metro to Metro", or "Metro to Non-Metro"
*note the tmsa==0 means indicates that an individual is currently in a non-metro area 

gen MtoM=1 if msamove==1 & tmsa[_n]~=0 & tmsa[_n-1]~=0

replace MtoM=0 if MtoM==.

label variable MtoM "Equals 1 if Metro to Metro move"

gen NMtoM=1 if msamove==1 & tmsa[_n]~=0 & tmsa[_n-1]==0

replace NMtoM=0 if NMtoM==.

label variable NMtoM "Equals 1 if Non-Metro to Metro move"

gen MtoNM=1 if msamove==1 & tmsa[_n]==0 & tmsa[_n-1]~=0

replace MtoNM=0 if MtoNM==.

label variable MtoNM "Equals 1 if Metro to Non-Metro move"

*now we want to generate a variable that will total the number of msamoves per unique individual 
*during the full sample period

by uid: egen totmsamoves=total(msamove)

label variable totmsamoves "Total MSA moves by individual throughout sample period"

*now we want to create a variable that captures the observation in the month prior to a MSa move

by uid: gen beforemsamove=1 if msamove[_n+1]==1

replace beforemsamove=0 if beforemsamove==.

label variable beforemsamove "Equals 1 if observation is month prior to a MSA move"

*Now we will produce a running sum of the MSA moves by person

by uid: gen summsamove=sum(msamove)

label variable summsamove "Equals running sum of a person's MSA moves"

*Now we will identify the last MSA move 

by uid: gen lastmsamove=1 if msamove==1 & summsamove[_n]==summsamove[_N]

replace lastmsamove=0 if lastmsamove==.

label variable lastmsamove "Equals 1 if a person's last MSA move"

*Now we will identify the observation just before the last MSA move 

by uid: gen beforelastmsamove=1 if beforemsamove==1 & lastmsamove[_n+1]==1

replace beforelastmsamove=0 if beforelastmsamove==.

label variable beforelastmsamove "Equals 1 if obs before a person's last MSA move"


*----------------------------------------------------Flag State Movers Within the 2001 Data Set--------------------------------------*


*now we will generate a variable to flag state movers within the dataset
*we will generate a varable called "statemove" and give it a value of 1 if the "uid" are the same but 
*the "State Code" changes over the monthly observations for each unique person

by uid: gen statemove=1 if uid[_n]==uid[_n-1] & tfipsst[_n]~=tfipsst[_n-1] 

replace statemove=0 if statemove==.

label variable statemove "Equals 1 if moved State location from prior month"

count if statemove==1

by uid: egen totstatemoves=total(statemove)

label variable totstatemoves "Total State moves by individual throughout sample period"

*now we want to create a variable that captures the observation in the month prior to a state move

by uid: gen beforestatemove=1 if statemove[_n+1]==1

replace beforestatemove=0 if beforestatemove==.

label variable beforestatemove "Equals 1 if observation is month prior to a State move"

*now we will save this file as a "allmove" file so that we keep the initial kept variable appended waves and "mover" kept 
*variable appended wave files separate just in case 

*Now we will produce a running sum of the state moves by person

by uid: gen sumstatemove=sum(statemove)

label variable sumstatemove "Equals running sum of a person's state moves"

*Now we will identify the last state move 

by uid: gen laststatemove=1 if statemove==1 & sumstatemove[_n]==sumstatemove[_N]

replace laststatemove=0 if laststatemove==.

label variable laststatemove "Equals 1 if a person's last state move"

*Now we will identify the observation just before the last State move 

by uid: gen beforelaststatemove=1 if beforestatemove==1 & laststatemove[_n+1]==1

replace beforelaststatemove=0 if beforelaststatemove==.

label variable beforelaststatemove "Equals 1 if obs before a person's last State move"

*--------------------------------------------------Identify Last Response for the Survey (Both Movers & Non-Movers)----------------------*

*We will generte a variable called "last_obs" to indicate the last survey response given by each individual
*While we will only use the last survey response for non-movers, this will also tell us how many unique individuals we have in the data set.

by uid: gen last_obs=1 if _n==_N

replace last_obs=0 if last_obs==.

label variable last_obs "Equal to 1 if it is the last response of either a mover or non-mover"

count if last_obs==1

*This is how many unique individuals you have. 

save "$dire\Assembled Data\01_allmove", replace

compress


*------------------------------------------------------For Life Changing Events (LCE) Tables--------------------------------------------*


*--------------------To Answer: What % of Those With LCE Moved?---------------------------*


*-----Married ---> Divorced/Separated/Widowed-----*

by uid: gen chg_married=1 if maritalstat[_n]!=maritalstat[_n-1] & maritalstat[_n-1]==1

replace chg_married=0 if chg_married==.

label variable chg_married "Equals 1 if Changed from Married to Div/Sep/Wid"

*The above generates a 1 if a person changes marital status from married to divorced/separated/widowed.

by uid: gen sum_chg_married=sum(chg_married)

label variable sum_chg_married "Equals running sum of number of changes from Married to Div/Sep/Wid"

*The above gives a running sum of the number of changes from married to divorced/separated/widowed.

*Now we will identify the last change from married for each person.

by uid: gen last_chg_married=1 if chg_married==1 & sum_chg_married[_n]==sum_chg_married[_N]

replace last_chg_married=0 if last_chg_married==.

label variable last_chg_married "Equals 1 if it is the last time a person changed from Married to Div/Sep/Wid"

*Now we will create an idicator variable equal to 1 if a person has 6 months before & 6 months after last marriage change

by uid: gen _6mo_chg_married=1 if (last_chg_married==1 & obsno[_n]>=obsno[_n-6]) & (last_chg_married==1 & obsno[_N]>=obsno[_n+6])

replace _6mo_chg_married=0 if _6mo_chg_married==. & last_chg_married==1

label variable _6mo_chg_married "Equals 1 if there is a 6 month window around the last marriage change"

by uid: gen sum_6mo_chg_married=sum(_6mo_chg_married)

*Now we will create an idicator variable equal to 1 if a person has 3 months before & 3 months after a last marriage change

by uid: gen _3mo_chg_married=1 if (last_chg_married==1 & obsno[_n]>=obsno[_n-3]) & (last_chg_married==1 & obsno[_N]>=obsno[_n+3])

replace _3mo_chg_married=0 if _3mo_chg_married==. & last_chg_married==1

label variable _3mo_chg_married "Equals 1 if there is a 3 month window around the last marriage change"

by uid: gen sum_3mo_chg_married=sum(_3mo_chg_married)

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen chg_married_msa_move_6mo=1 if (last_chg_married==1 & _6mo_chg_married==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n-4]==1 | lastmsamove[_n-5]==1|lastmsamove[_n-6]==1| /// 
lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1 | lastmsamove[_n+4]==1 | ///
lastmsamove[_n+5]==1 |lastmsamove[_n+6]==1))

replace chg_married_msa_move_6mo=0 if _6mo_chg_married==1 & chg_married_msa_move_6mo==.

replace chg_married_msa_move_6mo=-99 if last_chg_married==1 & _6mo_chg_married!=1

label variable chg_married_msa_move_6mo "Equals 1 if changed from married and moved MSAs w/n +-6 months of change"

by uid: gen sum_chg_married_msa_move_6mo=sum(chg_married_msa_move_6mo)

by uid: gen chg_married_msa_move_3mo=1 if (last_chg_married==1 & _3mo_chg_married==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1))

replace chg_married_msa_move_3mo=0 if _3mo_chg_married==1 & chg_married_msa_move_3mo==.

replace chg_married_msa_move_3mo=-99 if last_chg_married==1 & _3mo_chg_married!=1

label variable chg_married_msa_move_3mo "Equals 1 if changed from married and moved MSAs w/n +-3 months of change"

by uid: gen sum_chg_married_msa_move_3mo=sum(chg_married_msa_move_3mo)


*------------------------For State Moves-----------------------------------------------------*

by uid: gen chg_married_state_move_6mo=1 if (last_chg_married==1 & _6mo_chg_married==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n-4]==1 | laststatemove[_n-5]==1|laststatemove[_n-6]==1| /// laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1 | laststatemove[_n+4]==1 | ///
laststatemove[_n+5]==1 |laststatemove[_n+6]==1))

replace chg_married_state_move_6mo=0 if _6mo_chg_married==1 & chg_married_state_move_6mo==.

replace chg_married_state_move_6mo=-99 if last_chg_married==1 & _6mo_chg_married!=1

label variable chg_married_state_move_6mo "Equals 1 if changed from married and moved States w/n +-6 months of change"

by uid: gen sum_chg_married_state_move_6mo=sum(chg_married_state_move_6mo)

by uid: gen chg_married_state_move_3mo=1 if (last_chg_married==1 & _3mo_chg_married==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1))

replace chg_married_state_move_3mo=0 if _3mo_chg_married==1 & chg_married_state_move_3mo==.

replace chg_married_state_move_3mo=-99 if last_chg_married==1 & _3mo_chg_married!=1

label variable chg_married_state_move_3mo "Equals 1 if changed from married and moved States w/n +-3 months of change"

by uid: gen sum_chg_married_state_move_3mo=sum(chg_married_state_move_3mo)


*-----Single ---> Married-----*

by uid: gen chg_single=1 if maritalstat[_n]!=maritalstat[_n-1] & (maritalstat[_n-1]==4 | maritalstat[_n-1]==3 | maritalstat[_n-1]==2)

replace chg_single=0 if chg_single==.

label variable chg_single "Equals 1 if Changed from Single to Married"

*The above generates a 1 if a person changes marital status from single to married.

by uid: gen sum_chg_single=sum(chg_single)

label variable sum_chg_single "Equals running sum of number of changes from Single to Married"

*The above gives a running sum of the number of changes from single to married.

*Now we will identify the last change from single for each person.

by uid: gen last_chg_single=1 if chg_single==1 & sum_chg_single[_n]==sum_chg_single[_N]

replace last_chg_single=0 if last_chg_single==.

label variable last_chg_single "Equals 1 if it is the last time a person changed from Single to Married"

*Now we will create an idicator variable equal to 1 if a person has 6 months before & 6 months after last single change

by uid: gen _6mo_chg_single=1 if (last_chg_single==1 & obsno[_n]>=obsno[_n-6]) & (last_chg_single==1 & obsno[_N]>=obsno[_n+6])

replace _6mo_chg_single=0 if _6mo_chg_single==. & last_chg_single==1

label variable _6mo_chg_single "Equals 1 if there is a 6 month window around the last single change"

by uid: gen sum__6mo_chg_single=sum(_6mo_chg_single)

*Now we will create an idicator variable equal to 1 if a person has 3 months before & 3 months after a last single change

by uid: gen _3mo_chg_single=1 if (last_chg_single==1 & obsno[_n]>=obsno[_n-3]) & (last_chg_single==1 & obsno[_N]>=obsno[_n+3])

replace _3mo_chg_single=0 if _3mo_chg_single==. & last_chg_single==1

label variable _3mo_chg_single "Equals 1 if there is a 3 month window around the last single change"

by uid: gen sum__3mo_chg_single=sum(_3mo_chg_single)

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen chg_single_msa_move_6mo=1 if (last_chg_single==1 & _6mo_chg_single==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n-4]==1 | lastmsamove[_n-5]==1|lastmsamove[_n-6]==1| /// 
lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1 | lastmsamove[_n+4]==1 | ///
lastmsamove[_n+5]==1 |lastmsamove[_n+6]==1))

replace chg_single_msa_move_6mo=0 if _6mo_chg_single==1 & chg_single_msa_move_6mo==.

replace chg_single_msa_move_6mo=-99 if last_chg_single==1 & _6mo_chg_single!=1

label variable chg_single_msa_move_6mo "Equals 1 if changed from single and moved MSAs w/n +-6 months of change"

by uid: gen sum_chg_single_msa_move_6mo=sum(chg_single_msa_move_6mo)

by uid: gen chg_single_msa_move_3mo=1 if (last_chg_single==1 & _3mo_chg_single==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1))

replace chg_single_msa_move_3mo=0 if _3mo_chg_single==1 & chg_single_msa_move_3mo==.

replace chg_single_msa_move_3mo=-99 if last_chg_single==1 & _3mo_chg_single!=1

label variable chg_single_msa_move_3mo "Equals 1 if changed from single and moved MSAs w/n +-3 months of change"

by uid: gen sum_chg_single_msa_move_3mo=sum(chg_single_msa_move_3mo)


*------------------------For State Moves-----------------------------------------------------*

by uid: gen chg_single_state_move_6mo=1 if (last_chg_single==1 & _6mo_chg_single==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n-4]==1 | laststatemove[_n-5]==1|laststatemove[_n-6]==1| /// laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1 | laststatemove[_n+4]==1 | ///
laststatemove[_n+5]==1 |laststatemove[_n+6]==1))

replace chg_single_state_move_6mo=0 if _6mo_chg_single==1 & chg_single_state_move_6mo==.

replace chg_single_state_move_6mo=-99 if last_chg_single==1 & _6mo_chg_single!=1

label variable chg_single_state_move_6mo "Equals 1 if changed from single and moved States w/n +-6 months of change"

by uid: gen sum_chg_single_state_move_6mo=sum(chg_single_state_move_6mo)

by uid: gen chg_single_state_move_3mo=1 if (last_chg_single==1 & _3mo_chg_single==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1))

replace chg_single_state_move_3mo=0 if _3mo_chg_single==1 & chg_single_state_move_3mo==.

replace chg_single_state_move_3mo=-99 if last_chg_single==1 & _3mo_chg_single!=1

label variable chg_single_state_move_3mo "Equals 1 if changed from single and moved States w/n +-3 months of change"

by uid: gen sum_chg_single_state_move_3mo=sum(chg_single_state_move_3mo)


*-----No Child ---> 1st Child-----*

by uid: gen chg_nochild=1 if rfnkids[_n]==1 & rfnkids[_n-1]==0

replace chg_nochild=0 if chg_nochild==.

label variable chg_nochild "Equals 1 if Changed from No Child to First Child"

*The above generates a 1 if a person changes from having 0 children to having 1 child.

by uid: gen sum_chg_nochild=sum(chg_nochild)

label variable sum_chg_nochild "Equals running sum of number of changes from No Child to First Child"

*The above gives a running sum of the number of changes from no child to first child.

*Now we will identify the last change from no child to first child for each person.

by uid: gen last_chg_nochild=1 if chg_nochild==1 & sum_chg_nochild[_n]==sum_chg_nochild[_N]

replace last_chg_nochild=0 if last_chg_nochild==.

label variable last_chg_nochild "Equals 1 if it is the last time a person changed from no child to first child"

*Now we will create an idicator variable equal to 1 if a person has 6 months before & 6 months after last no child change

by uid: gen _6mo_chg_nochild=1 if (last_chg_nochild==1 & obsno[_n]>=obsno[_n-6]) & (last_chg_nochild==1 & obsno[_N]>=obsno[_n+6])

replace _6mo_chg_nochild=0 if _6mo_chg_nochild==. & last_chg_nochild==1

label variable _6mo_chg_nochild "Equals 1 if there is a 6 month window around the last no child change"

by uid: gen sum__6mo_chg_nochild=sum(_6mo_chg_nochild)

*Now we will create an idicator variable equal to 1 if a person has 3 months before & 3 months after a last no child change

by uid: gen _3mo_chg_nochild=1 if (last_chg_nochild==1 & obsno[_n]>=obsno[_n-3]) & (last_chg_nochild==1 & obsno[_N]>=obsno[_n+3])

replace _3mo_chg_nochild=0 if _3mo_chg_nochild==. & last_chg_nochild==1

label variable _3mo_chg_nochild "Equals 1 if there is a 3 month window around the last no child change"

by uid: gen sum__3mo_chg_nochild=sum(_3mo_chg_nochild)

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen chg_nochild_msa_move_6mo=1 if (last_chg_nochild==1 & _6mo_chg_nochild==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n-4]==1 | lastmsamove[_n-5]==1|lastmsamove[_n-6]==1| /// 
lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1 | lastmsamove[_n+4]==1 | ///
lastmsamove[_n+5]==1 |lastmsamove[_n+6]==1))

replace chg_nochild_msa_move_6mo=0 if _6mo_chg_nochild==1 & chg_nochild_msa_move_6mo==.

replace chg_nochild_msa_move_6mo=-99 if last_chg_nochild==1 & _6mo_chg_nochild!=1

label variable chg_nochild_msa_move_6mo "Equals 1 if changed from No Child to First Child and moved MSAs w/n +-6 months of change"

by uid: gen sum_chg_nochild_msa_move_6mo=sum(chg_nochild_msa_move_6mo)

by uid: gen chg_nochild_msa_move_3mo=1 if (last_chg_nochild==1 & _3mo_chg_nochild==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1))

replace chg_nochild_msa_move_3mo=0 if _3mo_chg_nochild==1 & chg_nochild_msa_move_3mo==.

replace chg_nochild_msa_move_3mo=-99 if last_chg_nochild==1 & _3mo_chg_nochild!=1

label variable chg_nochild_msa_move_3mo "Equals 1 if changed from No Child to First Child and moved MSAs w/n +-3 months of change"

by uid: gen sum_chg_nochild_msa_move_3mo=sum(chg_nochild_msa_move_3mo)


*------------------------For State Moves-----------------------------------------------------*

by uid: gen chg_nochild_state_move_6mo=1 if (last_chg_nochild==1 & _6mo_chg_nochild==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n-4]==1 | laststatemove[_n-5]==1|laststatemove[_n-6]==1| /// laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1 | laststatemove[_n+4]==1 | ///
laststatemove[_n+5]==1 |laststatemove[_n+6]==1))

replace chg_nochild_state_move_6mo=0 if _6mo_chg_nochild==1 & chg_nochild_state_move_6mo==.

replace chg_nochild_state_move_6mo=-99 if last_chg_nochild==1 & _6mo_chg_nochild!=1

label variable chg_nochild_state_move_6mo "Equals 1 if changed from No Child to First Child and moved States w/n +-6 months of change"

by uid: gen sum_chg_nochild_state_move_6mo=sum(chg_nochild_state_move_6mo)

by uid: gen chg_nochild_state_move_3mo=1 if (last_chg_nochild==1 & _3mo_chg_nochild==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1))

replace chg_nochild_state_move_3mo=0 if _3mo_chg_nochild==1 & chg_nochild_state_move_3mo==.

replace chg_nochild_state_move_3mo=-99 if last_chg_nochild==1 & _3mo_chg_nochild!=1

label variable chg_nochild_state_move_3mo "Equals 1 if changed from No Child to First Child and moved States w/n +-3 months of change"

by uid: gen sum_chg_nochild_state_move_3mo=sum(chg_nochild_state_move_3mo)


*-----1st Child ---> 2nd Child-----*

by uid: gen chg_firstchild=1 if rfnkids[_n]==2 & rfnkids[_n-1]==1

replace chg_firstchild=0 if chg_firstchild==.

label variable chg_firstchild "Equals 1 if Changed from First Child to Second Child"

*The above generates a 1 if a person changes from having 1 child to having 2 children.

by uid: gen sum_chg_firstchild=sum(chg_firstchild)

label variable sum_chg_firstchild "Equals running sum of number of changes from First Child to Second Child"

*The above gives a running sum of the number of changes from 1 child to 2 children.

*Now we will identify the last change from 1 child to 2 children for each person.

by uid: gen last_chg_firstchild=1 if chg_firstchild==1 & sum_chg_firstchild[_n]==sum_chg_firstchild[_N]

replace last_chg_firstchild=0 if last_chg_firstchild==.

label variable last_chg_firstchild "Equals 1 if it is the last time a person changed from First Child to Second Child"

*Now we will create an idicator variable equal to 1 if a person has 6 months before & 6 months after last 1st child change

by uid: gen _6mo_chg_firstchild=1 if (last_chg_firstchild==1 & obsno[_n]>=obsno[_n-6]) & (last_chg_firstchild==1 & obsno[_N]>=obsno[_n+6])

replace _6mo_chg_firstchild=0 if _6mo_chg_firstchild==. & last_chg_firstchild==1

label variable _6mo_chg_firstchild "Equals 1 if there is a 6 month window around the last 1st child change"

by uid: gen sum__6mo_chg_firstchild=sum(_6mo_chg_firstchild)

*Now we will create an idicator variable equal to 1 if a person has 3 months before & 3 months after a last 1st child change

by uid: gen _3mo_chg_firstchild=1 if (last_chg_firstchild==1 & obsno[_n]>=obsno[_n-3]) & (last_chg_firstchild==1 & obsno[_N]>=obsno[_n+3])

replace _3mo_chg_firstchild=0 if _3mo_chg_firstchild==. & last_chg_firstchild==1

label variable _3mo_chg_firstchild "Equals 1 if there is a 3 month window around the last 1st child change"

by uid: gen sum__3mo_chg_firstchild=sum(_3mo_chg_firstchild)

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen chg_firstchild_msa_move_6mo=1 if (last_chg_firstchild==1 & _6mo_chg_firstchild==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n-4]==1 | lastmsamove[_n-5]==1|lastmsamove[_n-6]==1| /// 
lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1 | lastmsamove[_n+4]==1 | ///
lastmsamove[_n+5]==1 |lastmsamove[_n+6]==1))

replace chg_firstchild_msa_move_6mo=0 if _6mo_chg_firstchild==1 & chg_firstchild_msa_move_6mo==.

replace chg_firstchild_msa_move_6mo=-99 if last_chg_firstchild==1 & _6mo_chg_firstchild!=1

label variable chg_firstchild_msa_move_6mo "Equals 1 if changed from First Chuild to Second Child and moved MSAs w/n +-6 months of change"

by uid: gen sum_chg_fstchild_msa_move_6mo=sum(chg_firstchild_msa_move_6mo)

by uid: gen chg_firstchild_msa_move_3mo=1 if (last_chg_firstchild==1 & _3mo_chg_firstchild==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1))

replace chg_firstchild_msa_move_3mo=0 if _3mo_chg_firstchild==1 & chg_firstchild_msa_move_3mo==.

replace chg_firstchild_msa_move_3mo=-99 if last_chg_firstchild==1 & _3mo_chg_firstchild!=1

label variable chg_firstchild_msa_move_3mo "Equals 1 if changed from First Child to Second Child and moved MSAs w/n +-3 months of change"

by uid: gen sum_chg_fstchild_msa_move_3mo=sum(chg_firstchild_msa_move_3mo)


*------------------------For State Moves-----------------------------------------------------*

by uid: gen chg_firstchild_state_move_6mo=1 if (last_chg_firstchild==1 & _6mo_chg_firstchild==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n-4]==1 | laststatemove[_n-5]==1|laststatemove[_n-6]==1| /// laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1 | laststatemove[_n+4]==1 | ///
laststatemove[_n+5]==1 |laststatemove[_n+6]==1))

replace chg_firstchild_state_move_6mo=0 if _6mo_chg_firstchild==1 & chg_firstchild_state_move_6mo==.

replace chg_firstchild_state_move_6mo=-99 if last_chg_firstchild==1 & _6mo_chg_firstchild!=1

label variable chg_firstchild_state_move_6mo "Equals 1 if changed from First Child to Second Child and moved States w/n +-6 months of change"

by uid: gen sum_chg_fstchild_state_move_6mo=sum(chg_firstchild_state_move_6mo)

by uid: gen chg_firstchild_state_move_3mo=1 if (last_chg_firstchild==1 & _3mo_chg_firstchild==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1))

replace chg_firstchild_state_move_3mo=0 if _3mo_chg_firstchild==1 & chg_firstchild_state_move_3mo==.

replace chg_firstchild_state_move_3mo=-99 if last_chg_firstchild==1 & _3mo_chg_firstchild!=1

label variable chg_firstchild_state_move_3mo "Equals 1 if changed from First Child to Second Child and moved States w/n +-3 months of change"

by uid: gen sum_chg_fstchild_state_move_3mo=sum(chg_firstchild_state_move_3mo)


*-----Oldest Child 4 years of age ---> Oldest Child 5 years of age-----*

by uid: gen chg_child4yo=1 if (ehotlunc[_n]==1 | ehotlunc[_n]==2) & ehotlunc[_n-1]==-1 & rfnkids[_n]>0

replace chg_child4yo=0 if chg_child4yo==.

label variable chg_child4yo "Equals 1 if Oldest Child turned 5"

*The above generates a 1 if a person's child turns 5 years old.

by uid: gen sum_chg_child4yo=sum(chg_child4yo)

label variable sum_chg_child4yo "Equals running sum of number of times a person's child turns 5 years old"

*The above gives a running sum of the number of times a person's child turns 5 years old.

*Now we will identify the last change from a person's child turning 5 years old.

by uid: gen last_chg_child4yo=1 if chg_child4yo==1 & sum_chg_child4yo[_n]==sum_chg_child4yo[_N]

replace last_chg_child4yo=0 if last_chg_child4yo==.

label variable last_chg_child4yo "Equals 1 if it is the last time a person's child turns 5 years old"

*Now we will create an idicator variable equal to 1 if a person has 6 months before & 6 months after last time a person's child turns 5 years old

by uid: gen _6mo_chg_child4yo=1 if (last_chg_child4yo==1 & obsno[_n]>=obsno[_n-6]) & (last_chg_child4yo==1 & obsno[_N]>=obsno[_n+6])

replace _6mo_chg_child4yo=0 if _6mo_chg_child4yo==. & last_chg_child4yo==1

label variable _6mo_chg_child4yo "Equals 1 if there is a 6 month window around the last time a person's child turns 5 years old"

by uid: gen sum__6mo_chg_child4yo=sum(_6mo_chg_child4yo)

*Now we will create an idicator variable equal to 1 if a person has 3 months before & 3 months after the last time a 
*person's child turns 5 years old

by uid: gen _3mo_chg_child4yo=1 if (last_chg_child4yo==1 & obsno[_n]>=obsno[_n-3]) & (last_chg_child4yo==1 & obsno[_N]>=obsno[_n+3])

replace _3mo_chg_child4yo=0 if _3mo_chg_child4yo==. & last_chg_child4yo==1

label variable _3mo_chg_child4yo "Equals 1 if there is a 3 month window around the last time a person's child turns 5 years old"

by uid: gen sum__3mo_chg_child4yo=sum(_3mo_chg_child4yo)

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen chg_child4yo_msa_move_6mo=1 if (last_chg_child4yo==1 & _6mo_chg_child4yo==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n-4]==1 | lastmsamove[_n-5]==1|lastmsamove[_n-6]==1| /// 
lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1 | lastmsamove[_n+4]==1 | ///
lastmsamove[_n+5]==1 |lastmsamove[_n+6]==1))

replace chg_child4yo_msa_move_6mo=0 if _6mo_chg_child4yo==1 & chg_child4yo_msa_move_6mo==.

replace chg_child4yo_msa_move_6mo=-99 if last_chg_child4yo==1 & _6mo_chg_child4yo!=1

label variable chg_child4yo_msa_move_6mo "Equals 1 if Oldest Child turned 5 and moved MSAs w/n +-6 months of change"

by uid: gen sum_chg_child4yo_msa_move_6mo=sum(chg_child4yo_msa_move_6mo)

by uid: gen chg_child4yo_msa_move_3mo=1 if (last_chg_child4yo==1 & _3mo_chg_child4yo==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1))

replace chg_child4yo_msa_move_3mo=0 if _3mo_chg_child4yo==1 & chg_child4yo_msa_move_3mo==.

replace chg_child4yo_msa_move_3mo=-99 if last_chg_child4yo==1 & _3mo_chg_child4yo!=1

label variable chg_child4yo_msa_move_3mo "Equals 1 if Oldest Child turned 5 and moved MSAs w/n +-3 months of change"

by uid: gen sum_chg_child4yo_msa_move_3mo=sum(chg_child4yo_msa_move_3mo)


*------------------------For State Moves-----------------------------------------------------*

by uid: gen chg_child4yo_state_move_6mo=1 if (last_chg_child4yo==1 & _6mo_chg_child4yo==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n-4]==1 | laststatemove[_n-5]==1|laststatemove[_n-6]==1| /// laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1 | laststatemove[_n+4]==1 | ///
laststatemove[_n+5]==1 |laststatemove[_n+6]==1))

replace chg_child4yo_state_move_6mo=0 if _6mo_chg_child4yo==1 & chg_child4yo_state_move_6mo==.

replace chg_child4yo_state_move_6mo=-99 if last_chg_child4yo==1 & _6mo_chg_child4yo!=1

label variable chg_child4yo_state_move_6mo "Equals 1 if Oldest Child turned 5 and moved States w/n +-6 months of change"

by uid: gen sum_chg_child4yo_state_move_6mo=sum(chg_child4yo_state_move_6mo)

by uid: gen chg_child4yo_state_move_3mo=1 if (last_chg_child4yo==1 & _3mo_chg_child4yo==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1))

replace chg_child4yo_state_move_3mo=0 if _3mo_chg_child4yo==1 & chg_child4yo_state_move_3mo==.

replace chg_child4yo_state_move_3mo=-99 if last_chg_child4yo==1 & _3mo_chg_child4yo!=1

label variable chg_child4yo_state_move_3mo "Equals 1 if Oldest Child turned 5 and moved States w/n +-3 months of change"

by uid: gen sum_chg_child4yo_state_move_3mo=sum(chg_child4yo_state_move_3mo)

compress

*-----Non-Disabled ---> Disabled-----*

by uid: gen chg_nondisabled=1 if disabled[_n]==1 & disabled[_n-1]==0

replace chg_nondisabled=0 if chg_nondisabled==.

label variable chg_nondisabled "Equals 1 if Changed to Disabled"

*The above generates a 1 if a person changes from non-disabled to disabled.

by uid: gen sum_chg_nondisabled=sum(chg_nondisabled)

label variable sum_chg_nondisabled "Equals running sum of number of times a person changes to disabled"

*The above gives a running sum of the number of times a person changes to disabled.

*Now we will identify the last change from a person changing to disabled.

by uid: gen last_chg_nondisabled=1 if chg_nondisabled==1 & sum_chg_nondisabled[_n]==sum_chg_nondisabled[_N]

replace last_chg_nondisabled=0 if last_chg_nondisabled==.

label variable last_chg_nondisabled "Equals 1 if it is the last time a person changed to disabled"

*Now we will create an idicator variable equal to 1 if a person has 6 months before & 6 months after last time a person changed to disabled

by uid: gen _6mo_chg_nondisabled=1 if (last_chg_nondisabled==1 & obsno[_n]>=obsno[_n-6]) & (last_chg_nondisabled==1 & obsno[_N]>=obsno[_n+6])

replace _6mo_chg_nondisabled=0 if _6mo_chg_nondisabled==. & last_chg_nondisabled==1

label variable _6mo_chg_nondisabled "Equals 1 if there is a 6 month window around the last time a person changed to disabled"

by uid: gen sum__6mo_chg_nondisabled=sum(_6mo_chg_nondisabled)

*Now we will create an idicator variable equal to 1 if a person has 3 months before & 3 months after the last time a 
*person changes to disabled

by uid: gen _3mo_chg_nondisabled=1 if (last_chg_nondisabled==1 & obsno[_n]>=obsno[_n-3]) & (last_chg_nondisabled==1 & obsno[_N]>=obsno[_n+3])

replace _3mo_chg_nondisabled=0 if _3mo_chg_nondisabled==. & last_chg_nondisabled==1

label variable _3mo_chg_nondisabled "Equals 1 if there is a 3 month window around the last time a person changed to disabled"

by uid: gen sum__3mo_chg_nondisabled=sum(_3mo_chg_nondisabled)

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen chg_nondisabled_msa_move_6mo=1 if (last_chg_nondisabled==1 & _6mo_chg_nondisabled==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n-4]==1 | lastmsamove[_n-5]==1|lastmsamove[_n-6]==1| /// 
lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1 | lastmsamove[_n+4]==1 | ///
lastmsamove[_n+5]==1 |lastmsamove[_n+6]==1))

replace chg_nondisabled_msa_move_6mo=0 if _6mo_chg_nondisabled==1 & chg_nondisabled_msa_move_6mo==.

replace chg_nondisabled_msa_move_6mo=-99 if last_chg_nondisabled==1 & _6mo_chg_nondisabled!=1

label variable chg_nondisabled_msa_move_6mo "Equals 1 if person changed to disabled and moved MSAs w/n +-6 months of change"

by uid: gen sum_chg_nondis_msa_move_6mo=sum(chg_nondisabled_msa_move_6mo)

by uid: gen chg_nondisabled_msa_move_3mo=1 if (last_chg_nondisabled==1 & _3mo_chg_nondisabled==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1))

replace chg_nondisabled_msa_move_3mo=0 if _3mo_chg_nondisabled==1 & chg_nondisabled_msa_move_3mo==.

replace chg_nondisabled_msa_move_3mo=-99 if last_chg_nondisabled==1 & _3mo_chg_nondisabled!=1

label variable chg_nondisabled_msa_move_3mo "Equals 1 if person changed to disabled and moved MSAs w/n +-3 months of change"

by uid: gen sum_chg_nondis_msa_move_3mo=sum(chg_nondisabled_msa_move_3mo)


*------------------------For State Moves-----------------------------------------------------*

by uid: gen chg_nondisabled_state_move_6mo=1 if (last_chg_nondisabled==1 & _6mo_chg_nondisabled==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n-4]==1 | laststatemove[_n-5]==1|laststatemove[_n-6]==1| /// laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1 | laststatemove[_n+4]==1 | ///
laststatemove[_n+5]==1 |laststatemove[_n+6]==1))

replace chg_nondisabled_state_move_6mo=0 if _6mo_chg_nondisabled==1 & chg_nondisabled_state_move_6mo==.

replace chg_nondisabled_state_move_6mo=-99 if last_chg_nondisabled==1 & _6mo_chg_nondisabled!=1

label variable chg_nondisabled_state_move_6mo "Equals 1 if person changed to disabled and moved States w/n +-6 months of change"

by uid: gen sum_chg_nondis_state_move_6mo=sum(chg_nondisabled_state_move_6mo)

by uid: gen chg_nondisabled_state_move_3mo=1 if (last_chg_nondisabled==1 & _3mo_chg_nondisabled==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1))

replace chg_nondisabled_state_move_3mo=0 if _3mo_chg_nondisabled==1 & chg_nondisabled_state_move_3mo==.

replace chg_nondisabled_state_move_3mo=-99 if last_chg_nondisabled==1 & _3mo_chg_nondisabled!=1

label variable chg_nondisabled_state_move_3mo "Equals 1 if person changed to disabled and moved States w/n +-3 months of change"

by uid: gen sum_chg_nondis_state_move_3mo=sum(chg_nondisabled_state_move_3mo)



*-----Employed ---> Unemployed-----*

by uid: gen chg_employed=1 if employed[_n]==0 & employed[_n-1]==1

replace chg_employed=0 if chg_employed==.

label variable chg_employed "Equals 1 if Changed to Unemployed"

*The above generates a 1 if a person changes from employed for the full month prior to obs to unemployed during the month of obs.

by uid: gen sum_chg_employed=sum(chg_employed)

label variable sum_chg_employed "Equals running sum of number of times a person changes to unemployed"

*The above gives a running sum of the number of times a person changes to unemployed.

*Now we will identify the last change from a person changing to unemployed.

by uid: gen last_chg_employed=1 if chg_employed==1 & sum_chg_employed[_n]==sum_chg_employed[_N]

replace last_chg_employed=0 if last_chg_employed==.

label variable last_chg_employed "Equals 1 if it is the last time a person changes to unemployed"

*Now we will create an idicator variable equal to 1 if a person has 6 months before & 6 months after last time a person changes to unemployed

by uid: gen _6mo_chg_employed=1 if (last_chg_employed==1 & obsno[_n]>=obsno[_n-6]) & (last_chg_employed==1 & obsno[_N]>=obsno[_n+6])

replace _6mo_chg_employed=0 if _6mo_chg_employed==. & last_chg_employed==1

label variable _6mo_chg_employed "Equals 1 if there is a 6 month window around the last time a person changes to unemployed"

by uid: gen sum__6mo_chg_employed=sum(_6mo_chg_employed)

*Now we will create an idicator variable equal to 1 if a person has 3 months before & 3 months after the last time
*a person changes to unemployed

by uid: gen _3mo_chg_employed=1 if (last_chg_employed==1 & obsno[_n]>=obsno[_n-3]) & (last_chg_employed==1 & obsno[_N]>=obsno[_n+3])

replace _3mo_chg_employed=0 if _3mo_chg_employed==. & last_chg_employed==1

label variable _3mo_chg_employed "Equals 1 if there is a 3 month window around the last time a person changes to unemployed"

by uid: gen sum__3mo_chg_employed=sum(_3mo_chg_employed)

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen chg_employed_msa_move_6mo=1 if (last_chg_employed==1 & _6mo_chg_employed==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n-4]==1 | lastmsamove[_n-5]==1|lastmsamove[_n-6]==1| /// 
lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1 | lastmsamove[_n+4]==1 | ///
lastmsamove[_n+5]==1 |lastmsamove[_n+6]==1))

replace chg_employed_msa_move_6mo=0 if _6mo_chg_employed==1 & chg_employed_msa_move_6mo==.

replace chg_employed_msa_move_6mo=-99 if last_chg_employed==1 & _6mo_chg_employed!=1

label variable chg_employed_msa_move_6mo "Equals 1 if person changed to unemployed and moved MSAs w/n +-6 months of change"

by uid: gen sum_chg_employed_msa_move_6mo=sum(chg_employed_msa_move_6mo)

by uid: gen chg_employed_msa_move_3mo=1 if (last_chg_employed==1 & _3mo_chg_employed==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1))

replace chg_employed_msa_move_3mo=0 if _3mo_chg_employed==1 & chg_employed_msa_move_3mo==.

replace chg_employed_msa_move_3mo=-99 if last_chg_employed==1 & _3mo_chg_employed!=1

label variable chg_employed_msa_move_3mo "Equals 1 if person changed to unemployed and moved MSAs w/n +-3 months of change"

by uid: gen sum_chg_employed_msa_move_3mo=sum(chg_employed_msa_move_3mo)


*------------------------For State Moves-----------------------------------------------------*

by uid: gen chg_employed_state_move_6mo=1 if (last_chg_employed==1 & _6mo_chg_employed==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n-4]==1 | laststatemove[_n-5]==1|laststatemove[_n-6]==1| /// laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1 | laststatemove[_n+4]==1 | ///
laststatemove[_n+5]==1 |laststatemove[_n+6]==1))

replace chg_employed_state_move_6mo=0 if _6mo_chg_employed==1 & chg_employed_state_move_6mo==.

replace chg_employed_state_move_6mo=-99 if last_chg_employed==1 & _6mo_chg_employed!=1

label variable chg_employed_state_move_6mo "Equals 1 if person changed to unemployed and moved States w/n +-6 months of change"

by uid: gen sum_chg_employed_state_move_6mo=sum(chg_employed_state_move_6mo)

by uid: gen chg_employed_state_move_3mo=1 if (last_chg_employed==1 & _3mo_chg_employed==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1))

replace chg_employed_state_move_3mo=0 if _3mo_chg_employed==1 & chg_employed_state_move_3mo==.

replace chg_employed_state_move_3mo=-99 if last_chg_employed==1 & _3mo_chg_employed!=1

label variable chg_employed_state_move_3mo "Equals 1 if person changed to unemployed and moved States w/n +-3 months of change"

by uid: gen sum_chg_employed_state_move_3mo=sum(chg_employed_state_move_3mo)


*-----Changed Employers----*

by uid: gen chg_employer=1 if estlemp1==2

replace chg_employer=0 if chg_employer==.

label variable chg_employer "Equals 1 if Changed Employer"

*The above generates a 1 if a person changes employer.

by uid: gen sum_chg_employer=sum(chg_employer)

label variable sum_chg_employer "Equals running sum of number of times a person changes employer"

*The above gives a running sum of the number of times a person changes employer.

*Now we will identify the last change from a person changing employers.

by uid: gen last_chg_employer=1 if chg_employer==1 & sum_chg_employer[_n]==sum_chg_employer[_N]

replace last_chg_employer=0 if last_chg_employer==.

label variable last_chg_employer "Equals 1 if it is the last time a person changes employer"

*Now we will create an idicator variable equal to 1 if a person has 6 months before & 6 months after last time a person changes employer

by uid: gen _6mo_chg_employer=1 if (last_chg_employer==1 & obsno[_n]>=obsno[_n-6]) & (last_chg_employer==1 & obsno[_N]>=obsno[_n+6])

replace _6mo_chg_employer=0 if _6mo_chg_employer==. & last_chg_employer==1

label variable _6mo_chg_employer "Equals 1 if there is a 6 month window around the last time a person changes employer"

by uid: gen sum__6mo_chg_employer=sum(_6mo_chg_employer)

*Now we will create an idicator variable equal to 1 if a person has 3 months before & 3 months after the last time
*a person changes employer

by uid: gen _3mo_chg_employer=1 if (last_chg_employer==1 & obsno[_n]>=obsno[_n-3]) & (last_chg_employer==1 & obsno[_N]>=obsno[_n+3])

replace _3mo_chg_employer=0 if _3mo_chg_employer==. & last_chg_employer==1

label variable _3mo_chg_employer "Equals 1 if there is a 3 month window around the last time a person changes employer"

by uid: gen sum__3mo_chg_employer=sum(_3mo_chg_employer)

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen chg_employer_msa_move_6mo=1 if (last_chg_employer==1 & _6mo_chg_employer==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n-4]==1 | lastmsamove[_n-5]==1|lastmsamove[_n-6]==1| /// 
lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1 | lastmsamove[_n+4]==1 | ///
lastmsamove[_n+5]==1 |lastmsamove[_n+6]==1))

replace chg_employer_msa_move_6mo=0 if _6mo_chg_employer==1 & chg_employer_msa_move_6mo==.

replace chg_employer_msa_move_6mo=-99 if last_chg_employer==1 & _6mo_chg_employer!=1

label variable chg_employer_msa_move_6mo "Equals 1 if person changed employer and moved MSAs w/n +-6 months of change"

by uid: gen sum_chg_employer_msa_move_6mo=sum(chg_employer_msa_move_6mo)

by uid: gen chg_employer_msa_move_3mo=1 if (last_chg_employer==1 & _3mo_chg_employer==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1))

replace chg_employer_msa_move_3mo=0 if _3mo_chg_employer==1 & chg_employer_msa_move_3mo==.

replace chg_employer_msa_move_3mo=-99 if last_chg_employer==1 & _3mo_chg_employer!=1

label variable chg_employer_msa_move_3mo "Equals 1 if person changed employer and moved MSAs w/n +-3 months of change"

by uid: gen sum_chg_employer_msa_move_3mo=sum(chg_employer_msa_move_3mo)


*------------------------For State Moves-----------------------------------------------------*

by uid: gen chg_employer_state_move_6mo=1 if (last_chg_employer==1 & _6mo_chg_employer==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n-4]==1 | laststatemove[_n-5]==1|laststatemove[_n-6]==1| /// laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1 | laststatemove[_n+4]==1 | ///
laststatemove[_n+5]==1 |laststatemove[_n+6]==1))

replace chg_employer_state_move_6mo=0 if _6mo_chg_employer==1 & chg_employer_state_move_6mo==.

replace chg_employer_state_move_6mo=-99 if last_chg_employer==1 & _6mo_chg_employer!=1

label variable chg_employer_state_move_6mo "Equals 1 if person changed employer and moved States w/n +-6 months of change"

by uid: gen sum_chg_employer_state_move_6mo=sum(chg_employer_state_move_6mo)

by uid: gen chg_employer_state_move_3mo=1 if (last_chg_employer==1 & _3mo_chg_employer==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1))

replace chg_employer_state_move_3mo=0 if _3mo_chg_employer==1 & chg_employer_state_move_3mo==.

replace chg_employer_state_move_3mo=-99 if last_chg_employer==1 & _3mo_chg_employer!=1

label variable chg_employer_state_move_3mo "Equals 1 if person changed employer and moved States w/n +-3 months of change"

by uid: gen sum_chg_employer_state_move_3mo=sum(chg_employer_state_move_3mo)


*-----Unemployed ---> Employed-----*

by uid: gen chg_unemployed=1 if employed[_n]==1 & employed[_n-1]==0

replace chg_unemployed=0 if chg_unemployed==.

label variable chg_unemployed "Equals 1 if Changed to Employed"

*The above generates a 1 if a person changes from unemployed for the full month prior to obs to employed during the month of obs.

by uid: gen sum_chg_unemployed=sum(chg_unemployed)

label variable sum_chg_unemployed "Equals running sum of number of times a person changes to employed"

*The above gives a running sum of the number of times a person changes to employed.

*Now we will identify the last change from a person changing to employed.

by uid: gen last_chg_unemployed=1 if chg_unemployed==1 & sum_chg_unemployed[_n]==sum_chg_unemployed[_N]

replace last_chg_unemployed=0 if last_chg_unemployed==.

label variable last_chg_unemployed "Equals 1 if it is the last time a person changes to employed"

*Now we will create an idicator variable equal to 1 if a person has 6 months before & 6 months after last time a person changes to employed

by uid: gen _6mo_chg_unemployed=1 if (last_chg_unemployed==1 & obsno[_n]>=obsno[_n-6]) & (last_chg_unemployed==1 & obsno[_N]>=obsno[_n+6])

replace _6mo_chg_unemployed=0 if _6mo_chg_unemployed==. & last_chg_unemployed==1

label variable _6mo_chg_unemployed "Equals 1 if there is a 6 month window around the last time a person changes to employed"

by uid: gen sum__6mo_chg_unemployed=sum(_6mo_chg_unemployed)

*Now we will create an idicator variable equal to 1 if a person has 3 months before & 3 months after the last time
*a person changes to employed

by uid: gen _3mo_chg_unemployed=1 if (last_chg_unemployed==1 & obsno[_n]>=obsno[_n-3]) & (last_chg_unemployed==1 & obsno[_N]>=obsno[_n+3])

replace _3mo_chg_unemployed=0 if _3mo_chg_unemployed==. & last_chg_unemployed==1

label variable _3mo_chg_unemployed "Equals 1 if there is a 3 month window around the last time a person changes to employed"

by uid: gen sum__3mo_chg_unemployed=sum(_3mo_chg_unemployed)

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen chg_unemployed_msa_move_6mo=1 if (last_chg_unemployed==1 & _6mo_chg_unemployed==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n-4]==1 | lastmsamove[_n-5]==1|lastmsamove[_n-6]==1| /// 
lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1 | lastmsamove[_n+4]==1 | ///
lastmsamove[_n+5]==1 |lastmsamove[_n+6]==1))

replace chg_unemployed_msa_move_6mo=0 if _6mo_chg_unemployed==1 & chg_unemployed_msa_move_6mo==.

replace chg_unemployed_msa_move_6mo=-99 if last_chg_unemployed==1 & _6mo_chg_unemployed!=1

label variable chg_unemployed_msa_move_6mo "Equals 1 if person changed to employed and moved MSAs w/n +-6 months of change"

by uid: gen sum_chg_unemp_msa_move_6mo=sum(chg_unemployed_msa_move_6mo)

by uid: gen chg_unemployed_msa_move_3mo=1 if (last_chg_unemployed==1 & _3mo_chg_unemployed==1 & (lastmsamove[_n]==1 | lastmsamove[_n-1]==1 | ///
lastmsamove[_n-2]==1 | lastmsamove[_n-3]==1 | lastmsamove[_n+1]==1 | lastmsamove[_n+2]==1 | lastmsamove[_n+3]==1))

replace chg_unemployed_msa_move_3mo=0 if _3mo_chg_unemployed==1 & chg_unemployed_msa_move_3mo==.

replace chg_unemployed_msa_move_3mo=-99 if last_chg_unemployed==1 & _3mo_chg_unemployed!=1

label variable chg_unemployed_msa_move_3mo "Equals 1 if person changed to employed and moved MSAs w/n +-3 months of change"

by uid: gen sum_chg_unemp_msa_move_3mo=sum(chg_unemployed_msa_move_3mo)


*------------------------For State Moves-----------------------------------------------------*

by uid: gen chg_unemployed_state_move_6mo=1 if (last_chg_unemployed==1 & _6mo_chg_unemployed==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n-4]==1 | laststatemove[_n-5]==1|laststatemove[_n-6]==1| /// laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1 | laststatemove[_n+4]==1 | ///
laststatemove[_n+5]==1 |laststatemove[_n+6]==1))

replace chg_unemployed_state_move_6mo=0 if _6mo_chg_unemployed==1 & chg_unemployed_state_move_6mo==.

replace chg_unemployed_state_move_6mo=-99 if last_chg_unemployed==1 & _6mo_chg_unemployed!=1

label variable chg_unemployed_state_move_6mo "Equals 1 if person changed to employed and moved States w/n +-6 months of change"

by uid: gen sum_chg_unemp_state_move_6mo=sum(chg_unemployed_state_move_6mo)

by uid: gen chg_unemployed_state_move_3mo=1 if (last_chg_unemployed==1 & _3mo_chg_unemployed==1 & (laststatemove[_n]==1 | laststatemove[_n-1]==1 | ///
laststatemove[_n-2]==1 | laststatemove[_n-3]==1 | laststatemove[_n+1]==1 | laststatemove[_n+2]==1 | laststatemove[_n+3]==1))

replace chg_unemployed_state_move_3mo=0 if _3mo_chg_unemployed==1 & chg_unemployed_state_move_3mo==.

replace chg_unemployed_state_move_3mo=-99 if last_chg_unemployed==1 & _3mo_chg_unemployed!=1

label variable chg_unemployed_state_move_3mo "Equals 1 if person changed to employed and moved States w/n +-3 months of change"

by uid: gen sum_chg_unemp_state_move_3mo=sum(chg_unemployed_state_move_3mo)

compress




*-----------------------To Answer: What % of Movers Had LCE?--------------------------------*

*Now we will create an idicator variable equal to 1 if a person has 6 months before & 6 months after a last state move

by uid: gen _6mo_statemove=1 if (laststatemove==1 & obsno[_n]>=obsno[_n-6]) & (laststatemove==1 & obsno[_N]>=obsno[_n+6])

replace _6mo_statemove=0 if _6mo_statemove==.

label variable _6mo_statemove "Equals 1 if there is a 6 month window around the last state move"

*Now we will create an idicator variable equal to 1 if a person has 3 months before & 3 months after a last state move

by uid: gen _3mo_statemove=1 if (laststatemove==1 & obsno[_n]>=obsno[_n-3]) & (laststatemove==1 & obsno[_N]>=obsno[_n+3])

label variable _3mo_statemove "Equals 1 if there is a 3 month window around the last state move"


*Now we will create an idicator variable equal to 1 if a person has 6 months before & 6 months after a last msa move

by uid: gen _6mo_msamove=1 if (lastmsamove==1 & obsno[_n]>=obsno[_n-6]) & (lastmsamove==1 & obsno[_N]>=obsno[_n+6])

replace _6mo_msamove=0 if _6mo_msamove==.

label variable _6mo_msamove "Equals 1 if there is a 6 month window around the last MSA move"

*Now we will create an idicator variable equal to 1 if a person has 3 months before & 3 months after a last msa move

by uid: gen _3mo_msamove=1 if (lastmsamove==1 & obsno[_n]>=obsno[_n-3]) & (lastmsamove==1 & obsno[_N]>=obsno[_n+3])

label variable _3mo_msamove "Equals 1 if there is a 3 month window around the last msa move"


*-----Married ---> Divorced/Separated/Widowed-----*

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen move_msa_chg_married_6mo=1 if (lastmsamove==1 & _6mo_msamove==1 & (chg_married[_n]==1 | chg_married[_n-1]==1 | ///
chg_married[_n-2]==1 | chg_married[_n-3]==1 | chg_married[_n-4]==1 | chg_married[_n-5]==1|chg_married[_n-6]==1| /// 
chg_married[_n+1]==1 | chg_married[_n+2]==1 | chg_married[_n+3]==1 | chg_married[_n+4]==1 | chg_married[_n+5]==1 | chg_married[_n+6]==1))

replace move_msa_chg_married_6mo=0 if _6mo_msamove==1 & move_msa_chg_married_6mo==.

replace move_msa_chg_married_6mo=-99 if lastmsamove==1 & _6mo_msamove!=1

label variable move_msa_chg_married_6mo "Equals 1 if moved Msas and changed from married w/n +-6 months of move"

by uid: gen move_msa_chg_married_3mo=1 if (lastmsamove==1 & _3mo_msamove==1 & (chg_married[_n]==1 | chg_married[_n-1]==1 | ///
chg_married[_n-2]==1 | chg_married[_n-3]==1 | chg_married[_n+1]==1 | chg_married[_n+2]==1 | chg_married[_n+3]==1))

replace move_msa_chg_married_3mo=0 if _3mo_msamove==1 & move_msa_chg_married_3mo==.

replace move_msa_chg_married_3mo=-99 if lastmsamove==1 & _3mo_msamove!=1

label variable move_msa_chg_married_3mo "Equals 1 if moved Msas and changed from married w/n +-3 months of move"


*------------------------For State Moves-------------------------------------------------------*

by uid: gen move_state_chg_married_6mo=1 if (laststatemove==1 & _6mo_statemove==1 & (chg_married[_n]==1 | chg_married[_n-1]==1 | ///
chg_married[_n-2]==1 | chg_married[_n-3]==1 | chg_married[_n-4]==1 | chg_married[_n-5]==1|chg_married[_n-6]==1| /// 
chg_married[_n+1]==1 | chg_married[_n+2]==1 | chg_married[_n+3]==1 | chg_married[_n+4]==1 | chg_married[_n+5]==1 | chg_married[_n+6]==1))

replace move_state_chg_married_6mo=0 if _6mo_statemove==1 & move_state_chg_married_6mo==.

replace move_state_chg_married_6mo=-99 if laststatemove==1 & _6mo_statemove!=1

label variable move_state_chg_married_6mo "Equals 1 if moved States and changed from married w/n +-6 months of move"

by uid: gen move_state_chg_married_3mo=1 if (laststatemove==1 & _3mo_statemove==1 & (chg_married[_n]==1 | chg_married[_n-1]==1 | ///
chg_married[_n-2]==1 | chg_married[_n-3]==1 | chg_married[_n+1]==1 | chg_married[_n+2]==1 | chg_married[_n+3]==1))

replace move_state_chg_married_3mo=0 if _3mo_statemove==1 & move_state_chg_married_3mo==.

replace move_state_chg_married_3mo=-99 if laststatemove==1 & _3mo_statemove!=1

label variable move_state_chg_married_3mo "Equals 1 if moved States and changed from married w/n +-3 months of move"


*-----Single ---> Married-----*

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen move_msa_chg_single_6mo=1 if (lastmsamove==1 & _6mo_msamove==1 & (chg_single[_n]==1 | chg_single[_n-1]==1 | ///
chg_single[_n-2]==1 | chg_single[_n-3]==1 | chg_single[_n-4]==1 | chg_single[_n-5]==1|chg_single[_n-6]==1| /// 
chg_single[_n+1]==1 | chg_single[_n+2]==1 | chg_single[_n+3]==1 | chg_single[_n+4]==1 | chg_single[_n+5]==1 | chg_single[_n+6]==1))

replace move_msa_chg_single_6mo=0 if _6mo_msamove==1 & move_msa_chg_single_6mo==.

replace move_msa_chg_single_6mo=-99 if lastmsamove==1 & _6mo_msamove!=1

label variable move_msa_chg_single_6mo "Equals 1 if moved Msas and changed from single w/n +-6 months of move"

by uid: gen move_msa_chg_single_3mo=1 if (lastmsamove==1 & _3mo_msamove==1 & (chg_single[_n]==1 | chg_single[_n-1]==1 | ///
chg_single[_n-2]==1 | chg_single[_n-3]==1 | chg_single[_n+1]==1 | chg_single[_n+2]==1 | chg_single[_n+3]==1))

replace move_msa_chg_single_3mo=0 if _3mo_msamove==1 & move_msa_chg_single_3mo==.

replace move_msa_chg_single_3mo=-99 if lastmsamove==1 & _3mo_msamove!=1

label variable move_msa_chg_single_3mo "Equals 1 if moved Msas and changed from single w/n +-3 months of move"


*------------------------For State Moves-------------------------------------------------------*

by uid: gen move_state_chg_single_6mo=1 if (laststatemove==1 & _6mo_statemove==1 & (chg_single[_n]==1 | chg_single[_n-1]==1 | ///
chg_single[_n-2]==1 | chg_single[_n-3]==1 | chg_single[_n-4]==1 | chg_single[_n-5]==1|chg_single[_n-6]==1| /// 
chg_single[_n+1]==1 | chg_single[_n+2]==1 | chg_single[_n+3]==1 | chg_single[_n+4]==1 | chg_single[_n+5]==1 | chg_single[_n+6]==1))

replace move_state_chg_single_6mo=0 if _6mo_statemove==1 & move_state_chg_single_6mo==.

replace move_state_chg_single_6mo=-99 if laststatemove==1 & _6mo_statemove!=1

label variable move_state_chg_single_6mo "Equals 1 if moved States and changed from single w/n +-6 months of move"

by uid: gen move_state_chg_single_3mo=1 if (laststatemove==1 & _3mo_statemove==1 & (chg_single[_n]==1 | chg_single[_n-1]==1 | ///
chg_single[_n-2]==1 | chg_single[_n-3]==1 | chg_single[_n+1]==1 | chg_single[_n+2]==1 | chg_single[_n+3]==1))

replace move_state_chg_single_3mo=0 if _3mo_statemove==1 & move_state_chg_single_3mo==.

replace move_state_chg_single_3mo=-99 if laststatemove==1 & _3mo_statemove!=1

label variable move_state_chg_single_3mo "Equals 1 if moved States and changed from single w/n +-3 months of move"


*-----No Child ---> 1st Child-----*


*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen move_msa_chg_nochild_6mo=1 if (lastmsamove==1 & _6mo_msamove==1 & (chg_nochild[_n]==1 | chg_nochild[_n-1]==1 | ///
chg_nochild[_n-2]==1 | chg_nochild[_n-3]==1 | chg_nochild[_n-4]==1 | chg_nochild[_n-5]==1|chg_nochild[_n-6]==1| /// 
chg_nochild[_n+1]==1 | chg_nochild[_n+2]==1 | chg_nochild[_n+3]==1 | chg_nochild[_n+4]==1 | chg_nochild[_n+5]==1 | chg_nochild[_n+6]==1))

replace move_msa_chg_nochild_6mo=0 if _6mo_msamove==1 & move_msa_chg_nochild_6mo==.

replace move_msa_chg_nochild_6mo=-99 if lastmsamove==1 & _6mo_msamove!=1

label variable move_msa_chg_nochild_6mo "Equals 1 if moved Msas and had first child w/n +-6 months of move"

by uid: gen move_msa_chg_nochild_3mo=1 if (lastmsamove==1 & _3mo_msamove==1 & (chg_nochild[_n]==1 | chg_nochild[_n-1]==1 | ///
chg_nochild[_n-2]==1 | chg_nochild[_n-3]==1 | chg_nochild[_n+1]==1 | chg_nochild[_n+2]==1 | chg_nochild[_n+3]==1))

replace move_msa_chg_nochild_3mo=0 if _3mo_msamove==1 & move_msa_chg_nochild_3mo==.

replace move_msa_chg_nochild_3mo=-99 if lastmsamove==1 & _3mo_msamove!=1

label variable move_msa_chg_nochild_3mo "Equals 1 if moved Msas and had first child w/n +-3 months of move"


*------------------------For State Moves-------------------------------------------------------*

by uid: gen move_state_chg_nochild_6mo=1 if (laststatemove==1 & _6mo_statemove==1 & (chg_nochild[_n]==1 | chg_nochild[_n-1]==1 | ///
chg_nochild[_n-2]==1 | chg_nochild[_n-3]==1 | chg_nochild[_n-4]==1 | chg_nochild[_n-5]==1|chg_nochild[_n-6]==1| /// 
chg_nochild[_n+1]==1 | chg_nochild[_n+2]==1 | chg_nochild[_n+3]==1 | chg_nochild[_n+4]==1 | chg_nochild[_n+5]==1 | chg_nochild[_n+6]==1))

replace move_state_chg_nochild_6mo=0 if _6mo_statemove==1 & move_state_chg_nochild_6mo==.

replace move_state_chg_nochild_6mo=-99 if laststatemove==1 & _6mo_statemove!=1

label variable move_state_chg_nochild_6mo "Equals 1 if moved States and had first child w/n +-6 months of move"

by uid: gen move_state_chg_nochild_3mo=1 if (laststatemove==1 & _3mo_statemove==1 & (chg_nochild[_n]==1 | chg_nochild[_n-1]==1 | ///
chg_nochild[_n-2]==1 | chg_nochild[_n-3]==1 | chg_nochild[_n+1]==1 | chg_nochild[_n+2]==1 | chg_nochild[_n+3]==1))

replace move_state_chg_nochild_3mo=0 if _3mo_statemove==1 & move_state_chg_nochild_3mo==.

replace move_state_chg_nochild_3mo=-99 if laststatemove==1 & _3mo_statemove!=1

label variable move_state_chg_nochild_3mo "Equals 1 if moved States and had first child w/n +-3 months of move"


*-----1st Child ---> 2nd Child-----*

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen move_msa_chg_firstchild_6mo=1 if (lastmsamove==1 & _6mo_msamove==1 & (chg_firstchild[_n]==1 | chg_firstchild[_n-1]==1 | ///
chg_firstchild[_n-2]==1 | chg_firstchild[_n-3]==1 | chg_firstchild[_n-4]==1 | chg_firstchild[_n-5]==1|chg_firstchild[_n-6]==1| /// 
chg_firstchild[_n+1]==1 | chg_firstchild[_n+2]==1 | chg_firstchild[_n+3]==1 | chg_firstchild[_n+4]==1 | chg_firstchild[_n+5]==1 | chg_firstchild[_n+6]==1))

replace move_msa_chg_firstchild_6mo=0 if _6mo_msamove==1 & move_msa_chg_firstchild_6mo==.

replace move_msa_chg_firstchild_6mo=-99 if lastmsamove==1 & _6mo_msamove!=1

label variable move_msa_chg_firstchild_6mo "Equals 1 if moved Msas and had second child w/n +-6 months of move"

by uid: gen move_msa_chg_firstchild_3mo=1 if (lastmsamove==1 & _3mo_msamove==1 & (chg_firstchild[_n]==1 | chg_firstchild[_n-1]==1 | ///
chg_firstchild[_n-2]==1 | chg_firstchild[_n-3]==1 | chg_firstchild[_n+1]==1 | chg_firstchild[_n+2]==1 | chg_firstchild[_n+3]==1))

replace move_msa_chg_firstchild_3mo=0 if _3mo_msamove==1 & move_msa_chg_firstchild_3mo==.

replace move_msa_chg_firstchild_3mo=-99 if lastmsamove==1 & _3mo_msamove!=1

label variable move_msa_chg_firstchild_3mo "Equals 1 if moved Msas and had second child w/n +-3 months of move"


*------------------------For State Moves-------------------------------------------------------*

by uid: gen move_state_chg_firstchild_6mo=1 if (laststatemove==1 & _6mo_statemove==1 & (chg_firstchild[_n]==1 | chg_firstchild[_n-1]==1 | ///
chg_firstchild[_n-2]==1 | chg_firstchild[_n-3]==1 | chg_firstchild[_n-4]==1 | chg_firstchild[_n-5]==1|chg_firstchild[_n-6]==1| /// 
chg_firstchild[_n+1]==1 | chg_firstchild[_n+2]==1 | chg_firstchild[_n+3]==1 | chg_firstchild[_n+4]==1 | chg_firstchild[_n+5]==1 | chg_firstchild[_n+6]==1))

replace move_state_chg_firstchild_6mo=0 if _6mo_statemove==1 & move_state_chg_firstchild_6mo==.

replace move_state_chg_firstchild_6mo=-99 if laststatemove==1 & _6mo_statemove!=1

label variable move_state_chg_firstchild_6mo "Equals 1 if moved States and had second child w/n +-6 months of move"

by uid: gen move_state_chg_firstchild_3mo=1 if (laststatemove==1 & _3mo_statemove==1 & (chg_firstchild[_n]==1 | chg_firstchild[_n-1]==1 | ///
chg_firstchild[_n-2]==1 | chg_firstchild[_n-3]==1 | chg_firstchild[_n+1]==1 | chg_firstchild[_n+2]==1 | chg_firstchild[_n+3]==1))

replace move_state_chg_firstchild_3mo=0 if _3mo_statemove==1 & move_state_chg_firstchild_3mo==.

replace move_state_chg_firstchild_3mo=-99 if laststatemove==1 & _3mo_statemove!=1

label variable move_state_chg_firstchild_3mo "Equals 1 if moved States and had second child w/n +-3 months of move"


*-----Oldest Child 4 years of age ---> Oldest Child 5 years of age-----*

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen move_msa_chg_child4yo_6mo=1 if (lastmsamove==1 & _6mo_msamove==1 & (chg_child4yo[_n]==1 | chg_child4yo[_n-1]==1 | ///
chg_child4yo[_n-2]==1 | chg_child4yo[_n-3]==1 | chg_child4yo[_n-4]==1 | chg_child4yo[_n-5]==1|chg_child4yo[_n-6]==1| /// 
chg_child4yo[_n+1]==1 | chg_child4yo[_n+2]==1 | chg_child4yo[_n+3]==1 | chg_child4yo[_n+4]==1 | chg_child4yo[_n+5]==1 | chg_child4yo[_n+6]==1))

replace move_msa_chg_child4yo_6mo=0 if _6mo_msamove==1 & move_msa_chg_child4yo_6mo==.

replace move_msa_chg_child4yo_6mo=-99 if lastmsamove==1 & _6mo_msamove!=1

label variable move_msa_chg_child4yo_6mo "Equals 1 if moved Msas and oldest child turned 5 w/n +-6 months of move"

by uid: gen move_msa_chg_child4yo_3mo=1 if (lastmsamove==1 & _3mo_msamove==1 & (chg_child4yo[_n]==1 | chg_child4yo[_n-1]==1 | ///
chg_child4yo[_n-2]==1 | chg_child4yo[_n-3]==1 | chg_child4yo[_n+1]==1 | chg_child4yo[_n+2]==1 | chg_child4yo[_n+3]==1))

replace move_msa_chg_child4yo_3mo=0 if _3mo_msamove==1 & move_msa_chg_child4yo_3mo==.

replace move_msa_chg_child4yo_3mo=-99 if lastmsamove==1 & _3mo_msamove!=1

label variable move_msa_chg_child4yo_3mo "Equals 1 if moved Msas and oldest child turned 5 w/n +-3 months of move"


*------------------------For State Moves-------------------------------------------------------*

by uid: gen move_state_chg_child4yo_6mo=1 if (laststatemove==1 & _6mo_statemove==1 & (chg_child4yo[_n]==1 | chg_child4yo[_n-1]==1 | ///
chg_child4yo[_n-2]==1 | chg_child4yo[_n-3]==1 | chg_child4yo[_n-4]==1 | chg_child4yo[_n-5]==1|chg_child4yo[_n-6]==1| /// 
chg_child4yo[_n+1]==1 | chg_child4yo[_n+2]==1 | chg_child4yo[_n+3]==1 | chg_child4yo[_n+4]==1 | chg_child4yo[_n+5]==1 | chg_child4yo[_n+6]==1))

replace move_state_chg_child4yo_6mo=0 if _6mo_statemove==1 & move_state_chg_child4yo_6mo==.

replace move_state_chg_child4yo_6mo=-99 if laststatemove==1 & _6mo_statemove!=1

label variable move_state_chg_child4yo_6mo "Equals 1 if moved States and oldest child turned 5 w/n +-6 months of move"

by uid: gen move_state_chg_child4yo_3mo=1 if (laststatemove==1 & _3mo_statemove==1 & (chg_child4yo[_n]==1 | chg_child4yo[_n-1]==1 | ///
chg_child4yo[_n-2]==1 | chg_child4yo[_n-3]==1 | chg_child4yo[_n+1]==1 | chg_child4yo[_n+2]==1 | chg_child4yo[_n+3]==1))

replace move_state_chg_child4yo_3mo=0 if _3mo_statemove==1 & move_state_chg_child4yo_3mo==.

replace move_state_chg_child4yo_3mo=-99 if laststatemove==1 & _3mo_statemove!=1

label variable move_state_chg_child4yo_3mo "Equals 1 if moved States and oldest child turned 5 w/n +-3 months of move"

compress


*-----Non-Disabled ---> Disabled-----*

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen move_msa_chg_nondisabled_6mo=1 if (lastmsamove==1 & _6mo_msamove==1 & (chg_nondisabled[_n]==1 | chg_nondisabled[_n-1]==1 | ///
chg_nondisabled[_n-2]==1 | chg_nondisabled[_n-3]==1 | chg_nondisabled[_n-4]==1 | chg_nondisabled[_n-5]==1|chg_nondisabled[_n-6]==1| /// 
chg_nondisabled[_n+1]==1 | chg_nondisabled[_n+2]==1 | chg_nondisabled[_n+3]==1 | chg_nondisabled[_n+4]==1 | chg_nondisabled[_n+5]==1 | chg_nondisabled[_n+6]==1))

replace move_msa_chg_nondisabled_6mo=0 if _6mo_msamove==1 & move_msa_chg_nondisabled_6mo==.

replace move_msa_chg_nondisabled_6mo=-99 if lastmsamove==1 & _6mo_msamove!=1

label variable move_msa_chg_nondisabled_6mo "Equals 1 if moved Msas and became disabled w/n +-6 months of move"

by uid: gen move_msa_chg_nondisabled_3mo=1 if (lastmsamove==1 & _3mo_msamove==1 & (chg_nondisabled[_n]==1 | chg_nondisabled[_n-1]==1 | ///
chg_nondisabled[_n-2]==1 | chg_nondisabled[_n-3]==1 | chg_nondisabled[_n+1]==1 | chg_nondisabled[_n+2]==1 | chg_nondisabled[_n+3]==1))

replace move_msa_chg_nondisabled_3mo=0 if _3mo_msamove==1 & move_msa_chg_nondisabled_3mo==.

replace move_msa_chg_nondisabled_3mo=-99 if lastmsamove==1 & _3mo_msamove!=1

label variable move_msa_chg_nondisabled_3mo "Equals 1 if moved Msas and became disabled w/n +-3 months of move"


*------------------------For State Moves-------------------------------------------------------*

by uid: gen move_state_chg_nondisabled_6mo=1 if (laststatemove==1 & _6mo_statemove==1 & (chg_nondisabled[_n]==1 | chg_nondisabled[_n-1]==1 | ///
chg_nondisabled[_n-2]==1 | chg_nondisabled[_n-3]==1 | chg_nondisabled[_n-4]==1 | chg_nondisabled[_n-5]==1|chg_nondisabled[_n-6]==1| /// 
chg_nondisabled[_n+1]==1 | chg_nondisabled[_n+2]==1 | chg_nondisabled[_n+3]==1 | chg_nondisabled[_n+4]==1 | chg_nondisabled[_n+5]==1 | chg_nondisabled[_n+6]==1))

replace move_state_chg_nondisabled_6mo=0 if _6mo_statemove==1 & move_state_chg_nondisabled_6mo==.

replace move_state_chg_nondisabled_6mo=-99 if laststatemove==1 & _6mo_statemove!=1

label variable move_state_chg_nondisabled_6mo "Equals 1 if moved States and became disabled w/n +-6 months of move"

by uid: gen move_state_chg_nondisabled_3mo=1 if (laststatemove==1 & _3mo_statemove==1 & (chg_nondisabled[_n]==1 | chg_nondisabled[_n-1]==1 | ///
chg_nondisabled[_n-2]==1 | chg_nondisabled[_n-3]==1 | chg_nondisabled[_n+1]==1 | chg_nondisabled[_n+2]==1 | chg_nondisabled[_n+3]==1))

replace move_state_chg_nondisabled_3mo=0 if _3mo_statemove==1 & move_state_chg_nondisabled_3mo==.

replace move_state_chg_nondisabled_3mo=-99 if laststatemove==1 & _3mo_statemove!=1

label variable move_state_chg_nondisabled_3mo "Equals 1 if moved States and became disabled w/n +-3 months of move"



*-----Employed ---> Unemployed-----*

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen move_msa_chg_employed_6mo=1 if (lastmsamove==1 & _6mo_msamove==1 & (chg_employed[_n]==1 | chg_employed[_n-1]==1 | ///
chg_employed[_n-2]==1 | chg_employed[_n-3]==1 | chg_employed[_n-4]==1 | chg_employed[_n-5]==1|chg_employed[_n-6]==1| /// 
chg_employed[_n+1]==1 | chg_employed[_n+2]==1 | chg_employed[_n+3]==1 | chg_employed[_n+4]==1 | chg_employed[_n+5]==1 | chg_employed[_n+6]==1))

replace move_msa_chg_employed_6mo=0 if _6mo_msamove==1 & move_msa_chg_employed_6mo==.

replace move_msa_chg_employed_6mo=-99 if lastmsamove==1 & _6mo_msamove!=1

label variable move_msa_chg_employed_6mo "Equals 1 if moved Msas and became unemployed w/n +-6 months of move"

by uid: gen move_msa_chg_employed_3mo=1 if (lastmsamove==1 & _3mo_msamove==1 & (chg_employed[_n]==1 | chg_employed[_n-1]==1 | ///
chg_employed[_n-2]==1 | chg_employed[_n-3]==1 | chg_employed[_n+1]==1 | chg_employed[_n+2]==1 | chg_employed[_n+3]==1))

replace move_msa_chg_employed_3mo=0 if _3mo_msamove==1 & move_msa_chg_employed_3mo==.

replace move_msa_chg_employed_3mo=-99 if lastmsamove==1 & _3mo_msamove!=1

label variable move_msa_chg_employed_3mo "Equals 1 if moved Msas and became unemployed w/n +-3 months of move"


*------------------------For State Moves-------------------------------------------------------*

by uid: gen move_state_chg_employed_6mo=1 if (laststatemove==1 & _6mo_statemove==1 & (chg_employed[_n]==1 | chg_employed[_n-1]==1 | ///
chg_employed[_n-2]==1 | chg_employed[_n-3]==1 | chg_employed[_n-4]==1 | chg_employed[_n-5]==1|chg_employed[_n-6]==1| /// 
chg_employed[_n+1]==1 | chg_employed[_n+2]==1 | chg_employed[_n+3]==1 | chg_employed[_n+4]==1 | chg_employed[_n+5]==1 | chg_employed[_n+6]==1))

replace move_state_chg_employed_6mo=0 if _6mo_statemove==1 & move_state_chg_employed_6mo==.

replace move_state_chg_employed_6mo=-99 if laststatemove==1 & _6mo_statemove!=1

label variable move_state_chg_employed_6mo "Equals 1 if moved States and became unemployed w/n +-6 months of move"

by uid: gen move_state_chg_employed_3mo=1 if (laststatemove==1 & _3mo_statemove==1 & (chg_employed[_n]==1 | chg_employed[_n-1]==1 | ///
chg_employed[_n-2]==1 | chg_employed[_n-3]==1 | chg_employed[_n+1]==1 | chg_employed[_n+2]==1 | chg_employed[_n+3]==1))

replace move_state_chg_employed_3mo=0 if _3mo_statemove==1 & move_state_chg_employed_3mo==.

replace move_state_chg_employed_3mo=-99 if laststatemove==1 & _3mo_statemove!=1

label variable move_state_chg_employed_3mo "Equals 1 if moved States and became unemployed w/n +-3 months of move"


*-----Changed Employers----*

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen move_msa_chg_employer_6mo=1 if (lastmsamove==1 & _6mo_msamove==1 & (chg_employer[_n]==1 | chg_employer[_n-1]==1 | ///
chg_employer[_n-2]==1 | chg_employer[_n-3]==1 | chg_employer[_n-4]==1 | chg_employer[_n-5]==1|chg_employer[_n-6]==1| /// 
chg_employer[_n+1]==1 | chg_employer[_n+2]==1 | chg_employer[_n+3]==1 | chg_employer[_n+4]==1 | chg_employer[_n+5]==1 | chg_employer[_n+6]==1))

replace move_msa_chg_employer_6mo=0 if _6mo_msamove==1 & move_msa_chg_employer_6mo==.

replace move_msa_chg_employer_6mo=-99 if lastmsamove==1 & _6mo_msamove!=1

label variable move_msa_chg_employer_6mo "Equals 1 if moved Msas and changed employers w/n +-6 months of move"

by uid: gen move_msa_chg_employer_3mo=1 if (lastmsamove==1 & _3mo_msamove==1 & (chg_employer[_n]==1 | chg_employer[_n-1]==1 | ///
chg_employer[_n-2]==1 | chg_employer[_n-3]==1 | chg_employer[_n+1]==1 | chg_employer[_n+2]==1 | chg_employer[_n+3]==1))

replace move_msa_chg_employer_3mo=0 if _3mo_msamove==1 & move_msa_chg_employer_3mo==.

replace move_msa_chg_employer_3mo=-99 if lastmsamove==1 & _3mo_msamove!=1

label variable move_msa_chg_employer_3mo "Equals 1 if moved Msas and changed employers w/n +-3 months of move"


*------------------------For State Moves-------------------------------------------------------*

by uid: gen move_state_chg_employer_6mo=1 if (laststatemove==1 & _6mo_statemove==1 & (chg_employer[_n]==1 | chg_employer[_n-1]==1 | ///
chg_employer[_n-2]==1 | chg_employer[_n-3]==1 | chg_employer[_n-4]==1 | chg_employer[_n-5]==1|chg_employer[_n-6]==1| /// 
chg_employer[_n+1]==1 | chg_employer[_n+2]==1 | chg_employer[_n+3]==1 | chg_employer[_n+4]==1 | chg_employer[_n+5]==1 | chg_employer[_n+6]==1))

replace move_state_chg_employer_6mo=0 if _6mo_statemove==1 & move_state_chg_employer_6mo==.

replace move_state_chg_employer_6mo=-99 if laststatemove==1 & _6mo_statemove!=1

label variable move_state_chg_employer_6mo "Equals 1 if moved States and changed employers w/n +-6 months of move"

by uid: gen move_state_chg_employer_3mo=1 if (laststatemove==1 & _3mo_statemove==1 & (chg_employer[_n]==1 | chg_employer[_n-1]==1 | ///
chg_employer[_n-2]==1 | chg_employer[_n-3]==1 | chg_employer[_n+1]==1 | chg_employer[_n+2]==1 | chg_employer[_n+3]==1))

replace move_state_chg_employer_3mo=0 if _3mo_statemove==1 & move_state_chg_employer_3mo==.

replace move_state_chg_employer_3mo=-99 if laststatemove==1 & _3mo_statemove!=1

label variable move_state_chg_employer_3mo "Equals 1 if moved States and changed employers w/n +-3 months of move"


*-----Employed ---> Unemployed-----*

*------------------------For MSA Moves-------------------------------------------------------*

by uid: gen move_msa_chg_unemployed_6mo=1 if (lastmsamove==1 & _6mo_msamove==1 & (chg_unemployed[_n]==1 | chg_unemployed[_n-1]==1 | ///
chg_unemployed[_n-2]==1 | chg_unemployed[_n-3]==1 | chg_unemployed[_n-4]==1 | chg_unemployed[_n-5]==1|chg_unemployed[_n-6]==1| /// 
chg_unemployed[_n+1]==1 | chg_unemployed[_n+2]==1 | chg_unemployed[_n+3]==1 | chg_unemployed[_n+4]==1 | chg_unemployed[_n+5]==1 | chg_unemployed[_n+6]==1))

replace move_msa_chg_unemployed_6mo=0 if _6mo_msamove==1 & move_msa_chg_unemployed_6mo==.

replace move_msa_chg_unemployed_6mo=-99 if lastmsamove==1 & _6mo_msamove!=1

label variable move_msa_chg_unemployed_6mo "Equals 1 if moved Msas and became employed w/n +-6 months of move"

by uid: gen move_msa_chg_unemployed_3mo=1 if (lastmsamove==1 & _3mo_msamove==1 & (chg_unemployed[_n]==1 | chg_unemployed[_n-1]==1 | ///
chg_unemployed[_n-2]==1 | chg_unemployed[_n-3]==1 | chg_unemployed[_n+1]==1 | chg_unemployed[_n+2]==1 | chg_unemployed[_n+3]==1))

replace move_msa_chg_unemployed_3mo=0 if _3mo_msamove==1 & move_msa_chg_unemployed_3mo==.

replace move_msa_chg_unemployed_3mo=-99 if lastmsamove==1 & _3mo_msamove!=1

label variable move_msa_chg_unemployed_3mo "Equals 1 if moved Msas and became employed w/n +-3 months of move"


*------------------------For State Moves-------------------------------------------------------*

by uid: gen move_state_chg_unemployed_6mo=1 if (laststatemove==1 & _6mo_statemove==1 & (chg_unemployed[_n]==1 | chg_unemployed[_n-1]==1 | ///
chg_unemployed[_n-2]==1 | chg_unemployed[_n-3]==1 | chg_unemployed[_n-4]==1 | chg_unemployed[_n-5]==1|chg_unemployed[_n-6]==1| /// 
chg_unemployed[_n+1]==1 | chg_unemployed[_n+2]==1 | chg_unemployed[_n+3]==1 | chg_unemployed[_n+4]==1 | chg_unemployed[_n+5]==1 | chg_unemployed[_n+6]==1))

replace move_state_chg_unemployed_6mo=0 if _6mo_statemove==1 & move_state_chg_unemployed_6mo==.

replace move_state_chg_unemployed_6mo=-99 if laststatemove==1 & _6mo_statemove!=1

label variable move_state_chg_unemployed_6mo "Equals 1 if moved States and became employed w/n +-6 months of move"

by uid: gen move_state_chg_unemployed_3mo=1 if (laststatemove==1 & _3mo_statemove==1 & (chg_unemployed[_n]==1 | chg_unemployed[_n-1]==1 | ///
chg_unemployed[_n-2]==1 | chg_unemployed[_n-3]==1 | chg_unemployed[_n+1]==1 | chg_unemployed[_n+2]==1 | chg_unemployed[_n+3]==1))

replace move_state_chg_unemployed_3mo=0 if _3mo_statemove==1 & move_state_chg_unemployed_3mo==.

replace move_state_chg_unemployed_3mo=-99 if laststatemove==1 & _3mo_statemove!=1

label variable move_state_chg_unemployed_3mo "Equals 1 if moved States and became employed w/n +-3 months of move"

compress


save "$dire\Assembled Data\01_allmove", replace



*------------------------------------------Save a File With MSA Movers' Before Last Move Response & Non-Movers' Last Response-------------*


*Now we will keep each non-mover's last survey response as well each msamover's obs prior to last msamove survey response and save it in a separate file

keep if (last_obs==1 & totmsamoves==0) | (beforelastmsamove==1)

drop  statemove totstatemoves beforestatemove sumstatemove laststatemove beforelaststatemove chg_married_state_move_6mo chg_married_state_move_3mo chg_single_state_move_6mo chg_single_state_move_3mo chg_nochild_state_move_6mo chg_nochild_state_move_3mo chg_firstchild_state_move_6mo chg_firstchild_state_move_3mo chg_child4yo_state_move_6mo chg_child4yo_state_move_3mo chg_nondisabled_state_move_6mo chg_nondisabled_state_move_3mo chg_employed_state_move_6mo chg_employed_state_move_3mo  chg_employer_state_move_6mo chg_employer_state_move_3mo chg_unemployed_state_move_6mo chg_unemployed_state_move_3mo _6mo_statemove _3mo_statemove move_state_chg_married_6mo move_state_chg_married_3mo move_state_chg_single_6mo move_state_chg_single_3mo move_state_chg_nochild_6mo move_state_chg_nochild_3mo move_state_chg_firstchild_6mo move_state_chg_firstchild_3mo move_state_chg_child4yo_6mo move_state_chg_child4yo_3mo move_state_chg_nondisabled_6mo move_state_chg_nondisabled_3mo move_state_chg_employed_6mo move_state_chg_employed_3mo move_state_chg_employer_6mo move_state_chg_employer_3mo move_state_chg_unemployed_6mo move_state_chg_unemployed_3mo

drop  sum_chg_married_state_move_6mo sum_chg_married_state_move_3mo sum_chg_single_state_move_6mo sum_chg_single_state_move_3mo sum_chg_nochild_state_move_6mo sum_chg_nochild_state_move_3mo sum_chg_fstchild_state_move_6mo sum_chg_fstchild_state_move_3mo sum_chg_child4yo_state_move_6mo sum_chg_child4yo_state_move_3mo sum_chg_nondis_state_move_6mo sum_chg_nondis_state_move_3mo sum_chg_employed_state_move_6mo sum_chg_employed_state_move_3mo sum_chg_employer_state_move_6mo sum_chg_employer_state_move_3mo sum_chg_unemp_state_move_6mo sum_chg_unemp_state_move_3mo

save "$dire\Assembled Data\01_metro_moves_prior_month", replace 


*------------------------------------------------Save a File With MSA Movers' Last Move Response & Non-Movers' Last Response-------------*

clear

use "$dire\Assembled Data\01_allmove"

*Now we will keep each non-mover's last survey response as well each msamover's last msamove survey response and save it in a separate file

keep if (last_obs==1 & totmsamoves==0) | (lastmsamove==1)

drop  statemove totstatemoves beforestatemove sumstatemove laststatemove beforelaststatemove chg_married_state_move_6mo chg_married_state_move_3mo chg_single_state_move_6mo chg_single_state_move_3mo chg_nochild_state_move_6mo chg_nochild_state_move_3mo chg_firstchild_state_move_6mo chg_firstchild_state_move_3mo chg_child4yo_state_move_6mo chg_child4yo_state_move_3mo chg_nondisabled_state_move_6mo chg_nondisabled_state_move_3mo chg_employed_state_move_6mo chg_employed_state_move_3mo  chg_employer_state_move_6mo chg_employer_state_move_3mo chg_unemployed_state_move_6mo chg_unemployed_state_move_3mo _6mo_statemove _3mo_statemove move_state_chg_married_6mo move_state_chg_married_3mo move_state_chg_single_6mo move_state_chg_single_3mo move_state_chg_nochild_6mo move_state_chg_nochild_3mo move_state_chg_firstchild_6mo move_state_chg_firstchild_3mo move_state_chg_child4yo_6mo move_state_chg_child4yo_3mo move_state_chg_nondisabled_6mo move_state_chg_nondisabled_3mo move_state_chg_employed_6mo move_state_chg_employed_3mo move_state_chg_employer_6mo move_state_chg_employer_3mo move_state_chg_unemployed_6mo move_state_chg_unemployed_3mo

drop  sum_chg_married_state_move_6mo sum_chg_married_state_move_3mo sum_chg_single_state_move_6mo sum_chg_single_state_move_3mo sum_chg_nochild_state_move_6mo sum_chg_nochild_state_move_3mo sum_chg_fstchild_state_move_6mo sum_chg_fstchild_state_move_3mo sum_chg_child4yo_state_move_6mo sum_chg_child4yo_state_move_3mo sum_chg_nondis_state_move_6mo sum_chg_nondis_state_move_3mo sum_chg_employed_state_move_6mo sum_chg_employed_state_move_3mo sum_chg_employer_state_move_6mo sum_chg_employer_state_move_3mo sum_chg_unemp_state_move_6mo sum_chg_unemp_state_move_3mo

save "$dire\Assembled Data\01_metro_moves_current_month", replace 


*------------------------------------------------Save a File With MSA Movers' Before Last Move Response & Last Move Response-------------*

clear

use "$dire\Assembled Data\01_allmove"

*Now we will keep each msamovers's last survey response as well each msamover's response prior to the last move and save it in a separate file

keep if (beforelastmsamove==1) | (lastmsamove==1)

drop  statemove totstatemoves beforestatemove sumstatemove laststatemove beforelaststatemove chg_married_state_move_6mo chg_married_state_move_3mo chg_single_state_move_6mo chg_single_state_move_3mo chg_nochild_state_move_6mo chg_nochild_state_move_3mo chg_firstchild_state_move_6mo chg_firstchild_state_move_3mo chg_child4yo_state_move_6mo chg_child4yo_state_move_3mo chg_nondisabled_state_move_6mo chg_nondisabled_state_move_3mo chg_employed_state_move_6mo chg_employed_state_move_3mo  chg_employer_state_move_6mo chg_employer_state_move_3mo chg_unemployed_state_move_6mo chg_unemployed_state_move_3mo _6mo_statemove _3mo_statemove move_state_chg_married_6mo move_state_chg_married_3mo move_state_chg_single_6mo move_state_chg_single_3mo move_state_chg_nochild_6mo move_state_chg_nochild_3mo move_state_chg_firstchild_6mo move_state_chg_firstchild_3mo move_state_chg_child4yo_6mo move_state_chg_child4yo_3mo move_state_chg_nondisabled_6mo move_state_chg_nondisabled_3mo move_state_chg_employed_6mo move_state_chg_employed_3mo move_state_chg_employer_6mo move_state_chg_employer_3mo move_state_chg_unemployed_6mo move_state_chg_unemployed_3mo

drop  sum_chg_married_state_move_6mo sum_chg_married_state_move_3mo sum_chg_single_state_move_6mo sum_chg_single_state_move_3mo sum_chg_nochild_state_move_6mo sum_chg_nochild_state_move_3mo sum_chg_fstchild_state_move_6mo sum_chg_fstchild_state_move_3mo sum_chg_child4yo_state_move_6mo sum_chg_child4yo_state_move_3mo sum_chg_nondis_state_move_6mo sum_chg_nondis_state_move_3mo sum_chg_employed_state_move_6mo sum_chg_employed_state_move_3mo sum_chg_employer_state_move_6mo sum_chg_employer_state_move_3mo sum_chg_unemp_state_move_6mo sum_chg_unemp_state_move_3mo

save "$dire\Assembled Data\01_metro_moves_prior_and_current_month", replace 


*------------------------------------------Save a File With State Movers' Before Last Move Response & Non-Movers' Last Response-------------*

clear

use "$dire\Assembled Data\01_allmove"

*Now we will keep each non-mover's last survey response as well each statemover's prior to last statemove survey response and save it in a separate file
*This is the same as what we did for msamoves above

keep if (last_obs==1 & totstatemoves==0) | (beforelaststatemove==1)

drop  msamove totmsamoves beforemsamove summsamove lastmsamove beforelastmsamove chg_married_msa_move_6mo chg_married_msa_move_3mo chg_single_msa_move_6mo chg_single_msa_move_3mo chg_nochild_msa_move_6mo chg_nochild_msa_move_3mo chg_firstchild_msa_move_6mo chg_firstchild_msa_move_3mo chg_child4yo_msa_move_6mo chg_child4yo_msa_move_3mo chg_nondisabled_msa_move_6mo chg_nondisabled_msa_move_3mo chg_employed_msa_move_6mo chg_employed_msa_move_3mo  chg_employer_msa_move_6mo chg_employer_msa_move_3mo chg_unemployed_msa_move_6mo chg_unemployed_msa_move_3mo _6mo_msamove _3mo_msamove move_msa_chg_married_6mo move_msa_chg_married_3mo move_msa_chg_single_6mo move_msa_chg_single_3mo move_msa_chg_nochild_6mo move_msa_chg_nochild_3mo move_msa_chg_firstchild_6mo move_msa_chg_firstchild_3mo move_msa_chg_child4yo_6mo move_msa_chg_child4yo_3mo move_msa_chg_nondisabled_6mo move_msa_chg_nondisabled_3mo move_msa_chg_employed_6mo move_msa_chg_employed_3mo move_msa_chg_employer_6mo move_msa_chg_employer_3mo move_msa_chg_unemployed_6mo move_msa_chg_unemployed_3mo

drop  sum_chg_married_msa_move_6mo sum_chg_married_msa_move_3mo sum_chg_single_msa_move_6mo sum_chg_single_msa_move_3mo sum_chg_nochild_msa_move_6mo sum_chg_nochild_msa_move_3mo sum_chg_fstchild_msa_move_6mo sum_chg_fstchild_msa_move_3mo sum_chg_child4yo_msa_move_6mo sum_chg_child4yo_msa_move_3mo sum_chg_nondis_msa_move_6mo sum_chg_nondis_msa_move_3mo sum_chg_employed_msa_move_6mo sum_chg_employed_msa_move_3mo sum_chg_employer_msa_move_6mo sum_chg_employer_msa_move_3mo sum_chg_unemp_msa_move_6mo sum_chg_unemp_msa_move_3mo

drop  MtoM NMtoM MtoNM

save "$dire\Assembled Data\01_state_moves_prior_month", replace 

*------------------------------------------------Save a File With State Movers' Last Move Response & Non-Movers' Last Response-------------*

clear

use "$dire\Assembled Data\01_allmove"

*Now we will keep each non-mover's last survey response as well each statemover's last statemove survey response and save it in a separate file
*This is the same as what we did for msamoves above

keep if (last_obs==1 & totstatemoves==0) | (laststatemove==1)

drop  msamove totmsamoves beforemsamove summsamove lastmsamove beforelastmsamove chg_married_msa_move_6mo chg_married_msa_move_3mo chg_single_msa_move_6mo chg_single_msa_move_3mo chg_nochild_msa_move_6mo chg_nochild_msa_move_3mo chg_firstchild_msa_move_6mo chg_firstchild_msa_move_3mo chg_child4yo_msa_move_6mo chg_child4yo_msa_move_3mo chg_nondisabled_msa_move_6mo chg_nondisabled_msa_move_3mo chg_employed_msa_move_6mo chg_employed_msa_move_3mo  chg_employer_msa_move_6mo chg_employer_msa_move_3mo chg_unemployed_msa_move_6mo chg_unemployed_msa_move_3mo _6mo_msamove _3mo_msamove move_msa_chg_married_6mo move_msa_chg_married_3mo move_msa_chg_single_6mo move_msa_chg_single_3mo move_msa_chg_nochild_6mo move_msa_chg_nochild_3mo move_msa_chg_firstchild_6mo move_msa_chg_firstchild_3mo move_msa_chg_child4yo_6mo move_msa_chg_child4yo_3mo move_msa_chg_nondisabled_6mo move_msa_chg_nondisabled_3mo move_msa_chg_employed_6mo move_msa_chg_employed_3mo move_msa_chg_employer_6mo move_msa_chg_employer_3mo move_msa_chg_unemployed_6mo move_msa_chg_unemployed_3mo

drop  sum_chg_married_msa_move_6mo sum_chg_married_msa_move_3mo sum_chg_single_msa_move_6mo sum_chg_single_msa_move_3mo sum_chg_nochild_msa_move_6mo sum_chg_nochild_msa_move_3mo sum_chg_fstchild_msa_move_6mo sum_chg_fstchild_msa_move_3mo sum_chg_child4yo_msa_move_6mo sum_chg_child4yo_msa_move_3mo sum_chg_nondis_msa_move_6mo sum_chg_nondis_msa_move_3mo sum_chg_employed_msa_move_6mo sum_chg_employed_msa_move_3mo sum_chg_employer_msa_move_6mo sum_chg_employer_msa_move_3mo sum_chg_unemp_msa_move_6mo sum_chg_unemp_msa_move_3mo

drop  MtoM NMtoM MtoNM

save "$dire\Assembled Data\01_state_moves_current_month", replace 

clear

*------------------------------------------------Save a File With State Movers' Before Last Move Response & Last Move Response-------------*

clear

use "$dire\Assembled Data\01_allmove"

*Now we will keep each state movers's last survey response as well each state mover's response prior to the last move and save it in a separate file

keep if (beforelaststatemove==1) | (laststatemove==1)

drop  msamove totmsamoves beforemsamove summsamove lastmsamove beforelastmsamove chg_married_msa_move_6mo chg_married_msa_move_3mo chg_single_msa_move_6mo chg_single_msa_move_3mo chg_nochild_msa_move_6mo chg_nochild_msa_move_3mo chg_firstchild_msa_move_6mo chg_firstchild_msa_move_3mo chg_child4yo_msa_move_6mo chg_child4yo_msa_move_3mo chg_nondisabled_msa_move_6mo chg_nondisabled_msa_move_3mo chg_employed_msa_move_6mo chg_employed_msa_move_3mo  chg_employer_msa_move_6mo chg_employer_msa_move_3mo chg_unemployed_msa_move_6mo chg_unemployed_msa_move_3mo _6mo_msamove _3mo_msamove move_msa_chg_married_6mo move_msa_chg_married_3mo move_msa_chg_single_6mo move_msa_chg_single_3mo move_msa_chg_nochild_6mo move_msa_chg_nochild_3mo move_msa_chg_firstchild_6mo move_msa_chg_firstchild_3mo move_msa_chg_child4yo_6mo move_msa_chg_child4yo_3mo move_msa_chg_nondisabled_6mo move_msa_chg_nondisabled_3mo move_msa_chg_employed_6mo move_msa_chg_employed_3mo move_msa_chg_employer_6mo move_msa_chg_employer_3mo move_msa_chg_unemployed_6mo move_msa_chg_unemployed_3mo

drop  sum_chg_married_msa_move_6mo sum_chg_married_msa_move_3mo sum_chg_single_msa_move_6mo sum_chg_single_msa_move_3mo sum_chg_nochild_msa_move_6mo sum_chg_nochild_msa_move_3mo sum_chg_fstchild_msa_move_6mo sum_chg_fstchild_msa_move_3mo sum_chg_child4yo_msa_move_6mo sum_chg_child4yo_msa_move_3mo sum_chg_nondis_msa_move_6mo sum_chg_nondis_msa_move_3mo sum_chg_employed_msa_move_6mo sum_chg_employed_msa_move_3mo sum_chg_employer_msa_move_6mo sum_chg_employer_msa_move_3mo sum_chg_unemp_msa_move_6mo sum_chg_unemp_msa_move_3mo

drop  MtoM NMtoM MtoNM

save "$dire\Assembled Data\01_state_moves_prior_and_current_month", replace 

log close

exit
